_positive = set(
    [
        "abba",
        "способност",
        "NO TRANSLATION",
        "апсолутно",
        "отпуштање",
        "апсорбира",
        "изобилство",
        "академски",
        "академија",
        "прифатливо",
        "прифаќање",
        "достапни",
        "признание",
        "сместување",
        "придружба",
        "оствари",
        "остварен",
        "достигнување",
        "договор",
        "одговорност",
        "одговорна",
        "акредитирани",
        "NO TRANSLATION",
        "точен",
        "кец",
        "постигне",
        "достигнување",
        "признание",
        "стекне",
        "стекнување",
        "акробат",
        "акција",
        "вистински",
        "острина",
        "acumen",
        "адаптирај се",
        "адаптибилен",
        "адреси",
        "адепт",
        "NO TRANSLATION",
        "додаток",
        "восхитувачки",
        "адмирал",
        "восхит",
        "му се восхитувам",
        "обожавател",
        "допуштена",
        "симпатична",
        "обожување",
        "обожавам",
        "однапред",
        "напредни",
        "напредок",
        "предност",
        "поволна",
        "доаѓањето",
        "авантура",
        "авантуристички",
        "препорачливо",
        "советува",
        "советник",
        "застапување",
        "естетски",
        "естетика",
        "љубезен",
        "љубов",
        "поврзани",
        "потврди",
        "афирмација",
        "потврден",
        "потврдно",
        "изобилство",
        "богат",
        "да си дозволи",
        "NO TRANSLATION",
        "агилен",
        "агилност",
        "се согласувам",
        "согласна",
        "се согласија",
        "согласувајќи се",
        "договор",
        "земјоделство",
        "напред",
        "помош",
        "помош",
        "алабастер",
        "будност",
        "NO TRANSLATION",
        "жив",
        "смирување",
        "верност",
        "алегро",
        "олесни",
        "олеснување",
        "сојузнички",
        "дозволено",
        "привлечност",
        "примамливо",
        "сојузник",
        "семоќен",
        "алоха",
        "неверојатно",
        "амбасадор",
        "амбиција",
        "подобри",
        "амин",
        "податлив",
        "измени",
        "се менува",
        "удобност",
        "пријатно",
        "пријателски",
        "амнестија",
        "NO TRANSLATION",
        "забавувај се",
        "забавуваше",
        "забава",
        "забавен",
        "аналитичар",
        "сидро",
        "прицврстување",
        "ангел",
        "ангелски",
        "анимирај",
        "анимиран",
        "антибиотици",
        "противотров",
        "антифунгални",
        "антички",
        "антисептик",
        "Апликација",
        "апологетски",
        "извини",
        "извинување",
        "апостол",
        "аплауз",
        "благодарност",
        "одобрување",
        "одобрување",
        "одобри",
        "одобрување",
        "АП",
        "способност",
        "археологија",
        "жесток",
        "плам",
        "аристократија",
        "аристократски",
        "оклоп",
        "арома",
        "предизвикува",
        "низа",
        "art",
        "артикулираат",
        "артикулација",
        "занаетчија",
        "NO TRANSLATION",
        "уметнички",
        "надмоќ",
        "искачување",
        "аспирација",
        "се стремат",
        "аспиранти",
        "собрание",
        "одобрување",
        "тврдејќи",
        "средства",
        "помош",
        "помош",
        "соработник",
        "assuage",
        "осигурување",
        "увери",
        "NO TRANSLATION",
        "изненадување",
        "астролог",
        "астронаут",
        "астроном",
        "остроумен",
        "атлетичар",
        "атлетски",
        "атом",
        "atone",
        "помирувањето",
        "приврзаност",
        "остварливи",
        "постигнување",
        "придружник",
        "внимание",
        "внимателен",
        "потврди",
        "адвокат",
        "атракција",
        "атрактивност",
        "зголемување",
        "август",
        "тетка",
        "аура",
        "Среќен",
        "автентична",
        "автентичност",
        "автор",
        "авторитативна",
        "авторитет",
        "овластување",
        "овластен",
        "аватар",
        "награда",
        "ај",
        "Ај",
        "бебе",
        "бакалауреат",
        "'рбетот",
        "рамнотежа",
        "избалансиран",
        "балада",
        "балет",
        "гласачко ливче",
        "балзам",
        "банкет",
        "крштевање",
        "крштевка",
        "бард",
        "зделка",
        "кошарка",
        "бастион",
        "бања",
        "зрак",
        "сјајно",
        "разубавување",
        "убава",
        "разубават",
        "убавина",
        "темел",
        "пиво",
        "дофат",
        "се спријатели",
        "верувајќи",
        "добротвор",
        "корисно",
        "корист",
        "добродушност",
        "бенигни",
        "лежај",
        "свршена",
        "подобрување",
        "пијалок",
        "библиски",
        "двојазично",
        "раѓање",
        "роденден",
        "непорочни",
        "благослови",
        "благословен",
        "благослов",
        "благослови",
        "блаженство",
        "блажен",
        "без крв",
        "цут",
        "цвет",
        "телохранител",
        "задебелен",
        "смелост",
        "зајакнување",
        "bonanza",
        "NO TRANSLATION",
        "бонус",
        "книга",
        "книжарница",
        "благодет",
        "богат",
        "награда",
        "букет",
        "мозоци",
        "храброст",
        "појадок",
        "булчински",
        "невеста",
        "младоженец",
        "деверуша",
        "осветли",
        "осветленост",
        "брилијантен",
        "брокат",
        "брат",
        "братство",
        "братски",
        "другар",
        "изгради",
        "зграда",
        "булдог",
        "блиндиран",
        "шапка",
        "автобус",
        "Батлер",
        "маслени",
        "buxom",
        "зуи",
        "такси",
        "кабинет",
        "кафе",
        "калкулатор",
        "теле",
        "смирен",
        "канари",
        "искрен",
        "кандидат",
        "захаросани",
        "капиталистички",
        "капетан",
        "очаровам",
        "волшебна",
        "кариера",
        "внимателен",
        "внимателно",
        "галење",
        "чувар",
        "carol",
        "каскада",
        "готовина",
        "категорично",
        "задоволи",
        "катарзичен",
        "катедрала",
        "претпазлив",
        "внимателно",
        "прослави",
        "славејќи",
        "прослава",
        "небесен",
        "центар",
        "стотник",
        "церебрална",
        "церемонија",
        "сигурност",
        "претседател",
        "претседателка",
        "шампион",
        "пеење",
        "полнач",
        "добротворни",
        "добротворна организација",
        "шарм",
        "шармантно",
        "чистота",
        "талкање",
        "контролна листа",
        "навиваат",
        "весели",
        "бодрост",
        "навива",
        "NO TRANSLATION",
        "хемичар",
        "негувај",
        "цреша",
        "главен",
        "дете",
        "детството",
        "chirp",
        "длето",
        "витештво",
        "чоколада",
        "избор",
        "хорот",
        "хорски",
        "хор",
        "избран",
        "супа",
        "хроника",
        "се смееш",
        "црква",
        "јаболковина",
        "обрежување",
        "граѓанин",
        "граѓански",
        "учтивост",
        "цивилизација",
        "цивилизиран",
        "визионер",
        "clap",
        "разјасни",
        "класичен",
        "класична",
        "класици",
        "класифицирам",
        "чист",
        "чистење",
        "чистота",
        "чисто",
        "очисти",
        "чистење",
        "дозвола",
        "чистота",
        "свештенички",
        "умен",
        "умешност",
        "климакс",
        "блискост",
        "затворање",
        "NO TRANSLATION",
        "кловн",
        "коалиција",
        "брег",
        "коегзистираат",
        "убедливо",
        "когнитивен",
        "кохерентност",
        "кохерентна",
        "кохезивен",
        "колективно",
        "полковник",
        "колосален",
        "удобност",
        "командант",
        "командантот",
        "комеморација",
        "комеморација",
        "комеморативна",
        "пофали",
        "пофално",
        "коментатор",
        "посветена",
        "commodore",
        "комонвелт",
        "комуницира",
        "комуникативни",
        "заедница",
        "заедница",
        "комутација",
        "менуваат",
        "придружник",
        "сочувство",
        "сочувствителен",
        "компатибилност",
        "компатибилен",
        "привлечни",
        "компензира",
        "компензаторни",
        "компетентност",
        "компетентност",
        "компетентен",
        "самозадоволство",
        "дополнување",
        "комплементарни",
        "целосно",
        "комплетноста",
        "завршувајќи",
        "завршување",
        "усогласеност",
        "согласност",
        "NO TRANSLATION",
        "составен",
        "композитор",
        "смиреноста",
        "сфати",
        "сеопфатна",
        "другар",
        "концентрично",
        "помирување",
        "склучување",
        "соглас",
        "согласност",
        "сочувство",
        "оправда",
        "погодна",
        "спроводливост",
        "конфедерација",
        "доверба",
        "уверени",
        "потврдено",
        "сообразност",
        "соодветен",
        "честитки",
        "општество",
        "конгруенција",
        "познавач",
        "совеста",
        "совесна",
        "свест",
        "осветување",
        "конзервација",
        "зачувување",
        "значителен",
        "внимателен",
        "конзистентност",
        "конзола",
        "согласка",
        "постојаност",
        "постојана",
        "уставно",
        "конструирај",
        "севкупно",
        "контакт",
        "контемплација",
        "содржина",
        "продолжи",
        "контура",
        "придонесе",
        "соработник",
        "погодност",
        "Погодно",
        "манастир",
        "конвенција",
        "познавач",
        "разговорно",
        "конвертира",
        "убеди",
        "кул",
        "свежина",
        "соработува",
        "соработка",
        "соработка",
        "соработка",
        "core",
        "крунисување",
        "корпорација",
        "телесен",
        "корективни",
        "преписка",
        "потврди",
        "космополитски",
        "пријатен",
        "совет",
        "советник",
        "советник",
        "брои",
        "грофица",
        "храброст",
        "храбри",
        "љубезен",
        "учтивост",
        "додворување",
        "залив",
        "завет",
        "лулка",
        "занает",
        "занаетчија",
        "крем",
        "креирај",
        "креативни",
        "доверба",
        "акредитивен",
        "кредибилитет",
        "веродостојна",
        "кредит",
        "NO TRANSLATION",
        "кредитирани",
        "крешендо",
        "критика",
        "крунисување",
        "клучно",
        "кристал",
        "умирам",
        "кулинарски",
        "кулминација",
        "се посветам",
        "култивирани",
        "одгледување",
        "култура",
        "лекува",
        "љубопитност",
        "навивам",
        "перниче",
        "клиент",
        "слатко",
        "секачи",
        "dame",
        "танц",
        "смел",
        "мила",
        "растрчани",
        "ќерка",
        "зората",
        "договор",
        "мил",
        "дебата",
        "пристојност",
        "пристоен",
        "декларативно",
        "посветеност",
        "брани",
        "бранеше",
        "бранител",
        "брани",
        "одбрана",
        "почит",
        "дефинитивно",
        "степен",
        "прекрасна",
        "делегат",
        "намерно",
        "вкусно",
        "задоволство",
        "воодушевен",
        "прекрасен",
        "избавување",
        "испорака",
        "демократија",
        "докажано",
        "демонстративен",
        "длабочина",
        "описни",
        "заслужуваат",
        "заслужено",
        "дизајнер",
        "пожелно",
        "желба",
        "желба",
        "дестинација",
        "детектирај",
        "откривање",
        "определување",
        "одлучен",
        "развива",
        "благочестив",
        "благочестив",
        "умешност",
        "дијамант",
        "дневник",
        "речник",
        "дидактички",
        "исхраната",
        "достоинствено",
        "Достоинство",
        "трудољубивост",
        "вечера",
        "дипломатија",
        "дипломатски",
        "режисер",
        "откритие",
        "NO TRANSLATION",
        "дискреција",
        "дискреционо",
        "дискусија",
        "дезинфекција",
        "отстранува",
        "дисеминираат",
        "дестилација",
        "разлика",
        "духовито",
        "насочуваат",
        "пренасочување",
        "божество",
        "лекар",
        "сторителот",
        "огорчено",
        "делфин",
        "Дон",
        "донација",
        "несомнено",
        "гулаб",
        "непријатен",
        "дует",
        "војводата",
        "издржливост",
        "трајни",
        "верен",
        "желни",
        "желба",
        "гранче",
        "заработи",
        "искрено",
        "искрено",
        "сериозност",
        "леснотија",
        "службеност",
        "NO TRANSLATION",
        "јаде",
        "екстази",
        "екстатично",
        "оформување",
        "да се едуцираат",
        "образовани",
        "образовни",
        "ефикасен",
        "ефикасност",
        "ефикасност",
        "ефикасен",
        "напор",
        "ејакулација",
        "елаборација",
        "возбуден",
        "старец",
        "старешини",
        "избира",
        "електричен",
        "електрична енергија",
        "елеганција",
        "елегантен",
        "надморска височина",
        "подобни",
        "елита",
        "елоквентност",
        "елоквентен",
        "разјасни",
        "еманципација",
        "прегратка",
        "emeritus",
        "еминенција",
        "еминентни",
        "еминентно",
        "NO TRANSLATION",
        "емпатија",
        "да ги поттикне",
        "имитираат",
        "овозможи",
        "овозможување",
        "маѓепсана",
        "маѓепсана",
        "волшебно",
        "NO TRANSLATION",
        "поттикнете",
        "охрабрување",
        "енциклопедија",
        "настојувај",
        "endow",
        "обдарени",
        "донација",
        "издржливост",
        "издржи",
        "енергичен",
        "верен",
        "ангажирање",
        "подобрување",
        "уживајте",
        "ужива",
        "просветли",
        "просветлување",
        "enliven",
        "збогатување",
        "ансамбл",
        "знак",
        "претприемнички",
        "забава",
        "забавуваат",
        "забавно",
        "забава",
        "ентузијазам",
        "ентузијаст",
        "NO TRANSLATION",
        "ефемерис",
        "еп",
        "олицетворение",
        "еднаквост",
        "подеднакво",
        "рамнотежа",
        "капитал",
        "нарачана",
        "ерудит",
        "esprit",
        "неопходно",
        "основана",
        "почит",
        "естетски",
        "етички",
        "етика",
        "зимзелени",
        "вечен",
        "очигледно",
        "еволуција",
        "возвиши",
        "егзалтација",
        "возвишен",
        "надмине",
        "ексел",
        "совршеност",
        "одлично",
        "размена",
        "возбудлив",
        "возбуда",
        "возбуди",
        "возбуден",
        "возбуда",
        "возбудливо",
        "пример",
        "ослободување",
        "возбуда",
        "проповедајте",
        "поттикнување",
        "постоење",
        "егзотично",
        "очекувајте",
        "очекувања",
        "целисходно",
        "експедиција",
        "искусен",
        "експерт",
        "експертиза",
        "објасни",
        "Исклучителна",
        "исклучително",
        "се прошири",
        "обемна",
        "екстра",
        "вонредна",
        "извлечете",
        "изобилство",
        "олеснување",
        "факти",
        "факултет",
        "NO TRANSLATION",
        "фер",
        "фер",
        "вера",
        "верен",
        "слава",
        "познат",
        "блискост",
        "познат",
        "славно",
        "фенси",
        "фанфари",
        "фасцинантно",
        "фасцинација",
        "модерен",
        "безобѕирно",
        "поволна",
        "омилен",
        "фаворизирање",
        "бестрашен",
        "подвиг",
        "функција",
        "Фелисити",
        "колеги",
        "стипендија",
        "женски",
        "плодна",
        "страст",
        "фестивал",
        "празнична",
        "NO TRANSLATION",
        "верност",
        "Фиеста",
        "конечно",
        "украси",
        "финес",
        "огнена топка",
        "огноотпорни",
        "цврстина",
        "NO TRANSLATION",
        "фитинг",
        "тела",
        "ласкави",
        "флота",
        "флексибилност",
        "цветни",
        "проток",
        "цветни",
        "флеш",
        "летање",
        "фокус",
        "љубов",
        "храна",
        "фудбал",
        "воздржаност",
        "fore",
        "предци",
        "горенаведеното",
        "надзорник",
        "претходник",
        "предвидуваат",
        "предвидени",
        "предвидување",
        "гради",
        "прости",
        "простено",
        "простува",
        "формативна",
        "формула",
        "NO TRANSLATION",
        "претстојни",
        "засили",
        "цврстина",
        "тврдина",
        "среќа",
        "среќа",
        "напред",
        "пронајден",
        "основа",
        "мирисна",
        "искрен",
        "искреност",
        "братски",
        "слобода",
        "слободно",
        "пријател",
        "пријателство",
        "пријателски",
        "пријателство",
        "жив",
        "весела",
        "скромен",
        "плодна",
        "исполни",
        "исполнување",
        "целосна",
        "полно",
        "забавно",
        "фундаментално",
        "осигурувач",
        "фузија",
        "добивка",
        "стекнување",
        "галантен",
        "галантерија",
        "изобилство",
        "градина",
        "гранат",
        "гарнизон",
        "весник",
        "опрема",
        "скапоцен камен",
        "општо",
        "великодушност",
        "дарежлив",
        "генијален",
        "генијалец",
        "благороден",
        "господин",
        "нежност",
        "гентри",
        "вистински",
        "гераниум",
        "подарок",
        "надарен",
        "гигантски",
        "кикотче",
        "трегер",
        "давање",
        "мило",
        "радост",
        "радост",
        "планирам",
        "трепер",
        "блескав",
        "глорификација",
        "прослави",
        "слава",
        "сјај",
        "Свети",
        "блескав",
        "бог",
        "побожно",
        "Божји дар",
        "злато",
        "добро",
        "добро",
        "добрина",
        "стока",
        "добра волја",
        "прекрасно",
        "госпел",
        "владее",
        "милоста",
        "доброто",
        "милостив",
        "милостиво",
        "дипломирањето",
        "внуци",
        "величественост",
        "баба",
        "грант",
        "одобрен",
        "благодарни",
        "задоволи",
        "благодарност",
        "поголемо",
        "величие",
        "зелена",
        "поздрав",
        "ѓердан",
        "насмевка",
        "grist",
        "песок",
        "темел",
        "расте",
        "раст",
        "гаранција",
        "чувар",
        "старател",
        "старателство",
        "губернаторски",
        "насоки",
        "водич",
        "водич",
        "гуру",
        "храброст",
        "гимнастичар",
        "живеалиште",
        "hale",
        "корисна",
        "среќно",
        "среќа",
        "среќен",
        "Харди",
        "хармонично",
        "хармонија",
        "жетва",
        "рај",
        "напредок",
        "исцели",
        "лекување",
        "здрава",
        "здрав",
        "искрено",
        "огништето",
        "од срце",
        "небесен",
        "небото",
        "тежок",
        "шлем",
        "помошник",
        "корисно",
        "билни",
        "херој",
        "херојски",
        "херојки",
        "хероина",
        "хероизмот",
        "најславни",
        "смешен",
        "веселост",
        "вработи",
        "хоби",
        "одмор",
        "светост",
        "свето",
        "почит",
        "хомологија",
        "искрен",
        "искреност",
        "мед",
        "меден месец",
        "чест",
        "чесен",
        "надеж",
        "надевајќи се",
        "хоризонт",
        "гостопримство",
        "домаќинство",
        "домаќинство",
        "прегратка",
        "хуман",
        "хуманитарна",
        "човештвото",
        "понизен",
        "смирено",
        "смирение",
        "хуморист",
        "хумористичен",
        "ура",
        "сточарство",
        "тишина",
        "колиба",
        "хигиенски",
        "химна",
        "идеализам",
        "идол",
        "NO TRANSLATION",
        "осветлување",
        "илустрирам",
        "славни",
        "имагинативна",
        "беспрекорно",
        "огромна",
        "миеше",
        "бесмртна",
        "пренесат",
        "непристрасен",
        "непристрасност",
        "беспрекорен",
        "отпорна",
        "важност",
        "важно",
        "импресионира",
        "впечаток",
        "да се подобри",
        "подобрени",
        "подобрување",
        "подобрување",
        "импровизираат",
        "неотуѓив",
        "инаугурација",
        "проникливо",
        "вклучуваат",
        "вклучени",
        "вклучувајќи",
        "инклузивна",
        "зголемување",
        "неизбришливо",
        "обештетување",
        "независност",
        "неуништив",
        "индивидуалност",
        "неукротим",
        "неискажлив",
        "ефтин",
        "непогрешлив",
        "бебе",
        "бесконечно",
        "бесконечност",
        "влијателни",
        "информации",
        "генијален",
        "наследство",
        "извонредна",
        "невиност",
        "невини",
        "невино",
        "едноставен",
        "иновираат",
        "иновации",
        "испитувач",
        "истрага",
        "испитувачки",
        "неразделен",
        "обележја",
        "инспектор",
        "инспирација",
        "инспирира",
        "инспириран",
        "инстинктивно",
        "инструкции",
        "настава",
        "инструктор",
        "инструментална",
        "осигурува",
        "непроменети",
        "интегритет",
        "интелект",
        "интелектуалец",
        "интелигенција",
        "интелигентен",
        "наменети",
        "секс",
        "интерес",
        "заинтересирани",
        "интересно",
        "внатрешни работи",
        "interlocutory",
        "интерлузија",
        "интимно",
        "интонација",
        "смешен",
        "интуиција",
        "интуитивен",
        "секогаш",
        "инвентивен",
        "пронаоѓач",
        "истражи",
        "заживее",
        "покана",
        "покани",
        "поканува",
        "железо",
        "непривлечен",
        "непобитен",
        "џекпот",
        "џем",
        "NO TRANSLATION",
        "работа",
        "се придружи",
        "се приклучи",
        "џокер",
        "се шегувам",
        "новинар",
        "патување",
        "весел",
        "радост",
        "весела",
        "весела",
        "весела",
        "јубилеј",
        "судски",
        "разумно",
        "скок",
        "правда",
        "оправдано",
        "оправдување",
        "одмор",
        "ken",
        "воведниот",
        "клучен збор",
        "вид",
        "добрина",
        "роднина",
        "цар",
        "бакнеж",
        "маче",
        "талент",
        "витез",
        "знаејќи",
        "знаење",
        "кудос",
        "пороѓај",
        "јагнешко",
        "земјиште",
        "слета",
        "ласер",
        "пофален",
        "се смееш",
        "се смее",
        "смеа",
        "лансира",
        "лауреат",
        "лаурел",
        "ловорики",
        "раскошен",
        "законски",
        "олово",
        "лидер",
        "лигата",
        "учат",
        "учење",
        "предавач",
        "слобода",
        "правен",
        "легализиран",
        "легендарниот",
        "читливост",
        "читлив",
        "слободно време",
        "лежерно",
        "лема",
        "благи",
        "лекција",
        "писмо",
        "ниво",
        "потпора",
        "ослободи",
        "ослободување",
        "слобода",
        "библиотека",
        "извор на енергија",
        "светилник",
        "вкус",
        "лингвист",
        "Лав",
        "литри",
        "логично",
        "долговечност",
        "господа",
        "љубовен",
        "љубов",
        "прекрасна",
        "NO TRANSLATION",
        "љубовник",
        "љубовен",
        "лојални",
        "лојалност",
        "среќа",
        "среќа",
        "претрупан",
        "сјај",
        "сјајни",
        "реткост",
        "луксузен",
        "луксуз",
        "лира",
        "лирски",
        "магично",
        "магнет",
        "магнетизам",
        "магнетит",
        "величественост",
        "прекрасен",
        "девица",
        "главна",
        "потпора",
        "величествен",
        "величие",
        "големи",
        "мнозинство",
        "управува",
        "управување",
        "мандарина",
        "машкост",
        "манифестира",
        "машко",
        "мана",
        "мажена",
        "манири",
        "производител",
        "март",
        "обележан",
        "се продава",
        "маркиз",
        "брак",
        "срцевина",
        "се ожени",
        "маршал",
        "чудо",
        "прекрасен",
        "прекрасно",
        "машки",
        "масажа",
        "господар",
        "ремек дело",
        "мајсторство",
        "колега",
        "брак",
        "матрон",
        "максимум",
        "градоначалник",
        "ливада",
        "мери",
        "медал",
        "посредува",
        "посредување",
        "посредник",
        "медицински",
        "NO TRANSLATION",
        "медитерански",
        "мешавина",
        "спомен",
        "незаборавно",
        "поправање",
        "мензи",
        "ментор",
        "милостив",
        "милост",
        "Спојте",
        "заслуги",
        "заслужен",
        "веселба",
        "весели",
        "Митрополит",
        "темелно",
        "микроскопија",
        "акушерство",
        "моќно",
        "мими",
        "внимателен",
        "mindfulness",
        "министерство",
        "чудо",
        "чудесен",
        "радост",
        "мисионер",
        "модел",
        "умерена",
        "модератор",
        "скромни",
        "скромност",
        "моментум",
        "монетарна",
        "пари",
        "монах",
        "споменик",
        "морално",
        "морал",
        "морал",
        "малтер",
        "мајчинство",
        "мотив",
        "подвижен",
        "двигател",
        "мускулест",
        "музика",
        "музички",
        "mutable",
        "взаемно",
        "nap",
        "натуралист",
        "пловни",
        "уредно",
        "нектар",
        "игла",
        "преговара",
        "преговарач",
        "сосед",
        "нерв",
        "гнездо",
        "благородништво",
        "благородна",
        "благородник",
        "номинација",
        "нормалност",
        "забележително",
        "познати личности",
        "NO TRANSLATION",
        "поим",
        "храна",
        "броеви",
        "Медицинска сестра",
        "расадник",
        "негуваат",
        "хранлива",
        "даб",
        "оаза",
        "заклетва",
        "послушност",
        "цел",
        "обврзувачки",
        "набљудувач",
        "може да се добие",
        "очигледно",
        "патник",
        "окупација",
        "окупирај",
        "понуда",
        "офицер",
        "офсет",
        "офшор",
        "сезнајни",
        "отвореност",
        "опера",
        "Особено",
        "можност",
        "оптимизам",
        "оптимист",
        "опција",
        "изборен",
        "оракул",
        "орација",
        "оркестар",
        "ракоположен",
        "уреден",
        "координација",
        "органски",
        "организација",
        "организира",
        "организирано",
        "оргазам",
        "оригиналност",
        "украсени",
        "украсен",
        "исход",
        "надвор",
        "нанадвор",
        "пресреќен",
        "огромно",
        "сопственост",
        "Пацифик",
        "рампа",
        "бања",
        "лопатка",
        "вкусен",
        "палијативна",
        "лек",
        "болка",
        "NO TRANSLATION",
        "папрака",
        "парагон",
        "најважен",
        "помилување",
        "родителството",
        "париетален",
        "Причекајте",
        "учество",
        "партнер",
        "партнерство",
        "страст",
        "страстни",
        "поминување на времето",
        "пастор",
        "тесто",
        "пасиште",
        "патент",
        "трпение",
        "трпелив",
        "патријархален",
        "патрон",
        "патронажа",
        "плати",
        "мир",
        "мирољубив",
        "мирен",
        "паун",
        "Пек",
        "особеност",
        "педигре",
        "безценните",
        "наклонетост",
        "гледаат",
        "забележлива",
        "трајни",
        "совршено",
        "совршенство",
        "изведувач",
        "perk",
        "дозвола",
        "вечни времиња",
        "упорност",
        "упорни",
        "убав",
        "релевантни",
        "фармацевтски",
        "филантроп",
        "филантропија",
        "филозоф",
        "Феникс",
        "фонетски",
        "лекар",
        "физика",
        "физиологија",
        "фигура",
        "изберете",
        "пикник",
        "живописно",
        "побожност",
        "пилула",
        "перница",
        "пилот",
        "врвот",
        "пионер",
        "побожен",
        "pith",
        "pivot",
        "спокоен",
        "планирање",
        "игрива",
        "игралиште",
        "игралиште",
        "пријатен",
        "задоволен",
        "пријатно",
        "залог",
        "пленарна седница",
        "обилен",
        "плексус",
        "слива",
        "излупен",
        "кадифе",
        "слој",
        "остроумен",
        "полицијата",
        "полицаец",
        "полски",
        "полиран",
        "љубезен",
        "учтивост",
        "NO TRANSLATION",
        "базен",
        "папа",
        "популарност",
        "популаризирана",
        "популација",
        "пренослив",
        "поседуваат",
        "питка",
        "потентност",
        "моќен",
        "моќно",
        "пракса",
        "практикуваше",
        "пракса",
        "пофалба",
        "пофали",
        "пофалба",
        "молете се",
        "претпазливост",
        "претходи",
        "приоритет",
        "драгоцено",
        "прецизен",
        "прецизност",
        "наклонетост",
        "доминантна",
        "Шешељ",
        "преферираат",
        "премиер",
        "простории",
        "подготви",
        "подготвени",
        "прецизност",
        "присуство",
        "присутен",
        "претставителни",
        "конзерванс",
        "зачувување",
        "претседател",
        "престиж",
        "престо",
        "убава",
        "преовладува",
        "превенција",
        "бесценета",
        "гордост",
        "свештеник",
        "свештенството",
        "свештеник",
        "првенство",
        "основно",
        "премиер",
        "буквар",
        "принц",
        "кнежев",
        "принцеза",
        "директорот",
        "чисто",
        "привилегиран",
        "чесност",
        "постапка",
        "поворка",
        "проктор",
        "набави",
        "неверојатно",
        "чудо",
        "продуцент",
        "производство",
        "производство",
        "продуктивен",
        "продуктивност",
        "професија",
        "професионален",
        "професор",
        "владеење",
        "умешен",
        "обилно",
        "напредок",
        "прогресија",
        "прогресивно",
        "плодна",
        "важност",
        "видливо",
        "ветување",
        "ветувајќи",
        "промоција",
        "реквизит",
        "правилно",
        "пророк",
        "профилактички",
        "исказ",
        "перспектива",
        "просперира",
        "просперитет",
        "просперитетна",
        "заштита",
        "заштита",
        "заштитни",
        "заштитник",
        "горди",
        "доказ",
        "пословичен",
        "обезбеди",
        "обезбедување",
        "внимателност",
        "разумно",
        "псалм",
        "јавноста",
        "повлече",
        "проповедник",
        "точен",
        "точност",
        "кученце",
        "чисто",
        "прочистување",
        "прочистете",
        "пурист",
        "чистота",
        "purr",
        "необично",
        "квалификувани",
        "квалификациите",
        "потрага",
        "прашање",
        "брзина",
        "непостојана",
        "тивок",
        "кинин",
        "сјај",
        "светли",
        "зрачи",
        "радио",
        "извалкан",
        "занес",
        "рационално",
        "читач",
        "лесно",
        "готовност",
        "читање",
        "повторно потврди",
        "реално",
        "причина",
        "успокојување",
        "Успокојувај",
        "попуст",
        "преиспитување",
        "примени",
        "примање",
        "NO TRANSLATION",
        "реципроцитет",
        "рекултивација",
        "прикривам",
        "препознатливо",
        "препорачај",
        "помирување",
        "преиспитување",
        "реконструирај",
        "реконструкција",
        "рекордер",
        "надомести",
        "обновување",
        "рекреација",
        "рекреативни",
        "исправи",
        "откуп",
        "надомест",
        "рафинирај",
        "префинетост",
        "реформи",
        "реформација",
        "реформатор",
        "освежувачки",
        "реновирање",
        "кралски",
        "регент",
        "регуларност",
        "регулираат",
        "рехабилитира",
        "рехабилитација",
        "надомести",
        "надоместок",
        "засилување",
        "вратете",
        "Радувај се",
        "радувај се",
        "подмладување",
        "подмладена",
        "релаксација",
        "релевантни",
        "доверливост",
        "сигурен",
        "потпирање",
        "олеснување",
        "ослободување",
        "римејк",
        "извонреден",
        "NO TRANSLATION",
        "лек",
        "ремисија",
        "реконструирам",
        "ренесанса",
        "направи",
        "обновување",
        "реновирање",
        "реновирање",
        "слава",
        "познат",
        "реорганизирам",
        "репарација",
        "отплати",
        "покај се",
        "надополнувајте",
        "полна",
        "новинар",
        "одмор",
        "претставен",
        "репродуктивно",
        "реномирани",
        "спаси",
        "резерва",
        "жител",
        "еластични",
        "резистивни",
        "одлучно",
        "ресурси",
        "почит",
        "угледност",
        "респектабилна",
        "почитувана",
        "почитувајќи го",
        "почитува",
        "одмор",
        "сјајна",
        "одговорен",
        "одговора",
        "одмор",
        "мирен",
        "реституција",
        "ресторативна",
        "враќање",
        "воздржаност",
        "продолжување",
        "задржување",
        "обединување",
        "уживајте",
        "извици",
        "почитувај",
        "почит",
        "почитувај",
        "сон",
        "ревидирај",
        "преродба",
        "револуционерен",
        "награда",
        "ритам",
        "ритмички",
        "лента",
        "богатство",
        "возач",
        "праведен",
        "право",
        "со право",
        "зрели",
        "зрее",
        "расте",
        "возбудлив",
        "roadster",
        "робустен",
        "рок",
        "Шипка",
        "рикање",
        "романса",
        "романтична",
        "романтизам",
        "romp",
        "вкоренето",
        "розова",
        "рота",
        "рутински",
        "кралско семејство",
        "рубрика",
        "Рут",
        "безбеден",
        "заштита",
        "мудрец",
        "светец",
        "свети",
        "плата",
        "истакнати",
        "пофалба",
        "поздрав",
        "спасение",
        "спаси",
        "самурај",
        "осветување",
        "посвети",
        "светилиште",
        "сангвини",
        "санитарни",
        "сатен",
        "задоволително",
        "задоволен",
        "спаси",
        "заштеди",
        "мирис",
        "солени",
        "такт",
        "научник",
        "стипендија",
        "научни",
        "научник",
        "NO TRANSLATION",
        "резултат",
        "писар",
        "скрипта",
        "многу вкусно",
        "скулптура",
        "море",
        "печат",
        "зачинети",
        "секретаријат",
        "стаж",
        "сензационално",
        "смисла",
        "сензибилитет",
        "разумно",
        "сензуалност",
        "сензуална",
        "сентиментален",
        "сентименталност",
        "стража",
        "спокојство",
        "проповед",
        "серум",
        "settlor",
        "секс",
        "форма",
        "снажен",
        "Сподели",
        "засолниште",
        "пастир",
        "Свети",
        "сјае",
        "шопинг",
        "рамо",
        "лукав",
        "свила",
        "поедноставување",
        "искрено",
        "искреност",
        "пее",
        "посебно",
        "господине",
        "сестринство",
        "квалификувани",
        "вешт",
        "небото",
        "чеша",
        "елегантен",
        "тенки",
        "тенок",
        "насмевка",
        "насмеани",
        "поразен",
        "мазност",
        "snicker",
        "трезвеност",
        "друштвени",
        "утеха",
        "војник",
        "солидна",
        "цврстина",
        "решение",
        "солвентност",
        "сонар",
        "соната",
        "сонет",
        "звучни",
        "смири",
        "смирувачки",
        "NO TRANSLATION",
        "стабилност",
        "супа",
        "спа",
        "пространа",
        "спаниел",
        "Искра",
        "посебно",
        "NO TRANSLATION",
        "говор",
        "брзо",
        "правопис",
        "зачин",
        "дух",
        "духови",
        "прекрасен",
        "сјај",
        "спонзор",
        "беспрекорен",
        "брачен другар",
        "смрека",
        "стабилно",
        "стаккато",
        "нерѓосувачки",
        "жерел",
        "цврсто",
        "издржливост",
        "стои",
        "ѕвезда",
        "ѕвезда",
        "ѕвезденото",
        "величествен",
        "изјава",
        "статуа",
        "статус",
        "верен",
        "цврст",
        "ѕвездени",
        "стјуардеса",
        "тишина",
        "продавница",
        "едноставно",
        "стратешки",
        "стратег",
        "сила",
        "зајакнување",
        "зајакнување",
        "впечатливо",
        "впечатливо",
        "силно",
        "структура",
        "обетка",
        "студија",
        "цврсти",
        "сублимација",
        "супстанција",
        "суштински",
        "успее",
        "наследувајќи",
        "успех",
        "успешна",
        "содржаен",
        "доволност",
        "шеќер",
        "погоден",
        "sultry",
        "сонце",
        "сончево",
        "зајдисонце",
        "сонце",
        "врвен",
        "натчовечки",
        "супериорен",
        "супериорност",
        "супермен",
        "суперѕвезда",
        "молитва",
        "резерви",
        "снабдување",
        "поддржан",
        "поддржувач",
        "поддршка",
        "врховен",
        "врвно",
        "гаранција",
        "претпоставка",
        "надминувајќи",
        "изненадување",
        "геодетски",
        "преживее",
        "се заколнам",
        "слатко",
        "срдечна",
        "слатко",
        "сладост",
        "слатки",
        "брза",
        "пливаат",
        "симболично",
        "симетрична",
        "симетрија",
        "симпатична",
        "сочувство",
        "симфонија",
        "синхронизирај",
        "синергистички",
        "синод",
        "такт",
        "приказна",
        "талент",
        "талисман",
        "зборувај",
        "троен",
        "задача",
        "вкусно",
        "вкусна",
        "учат",
        "наставник",
        "технологија",
        "воздржаност",
        "темпериран",
        "издржан",
        "издржлив",
        "издржливост",
        "закуп",
        "закупец",
        "тендер",
        "нежност",
        "благодарен",
        "благодарност",
        "теоретски",
        "терапевтски",
        "терапевтика",
        "NO TRANSLATION",
        "чистокрвни",
        "внимателен",
        "промисленост",
        "штедливост",
        "возбуда",
        "возбудливо",
        "просперитетна",
        "престол",
        "скокање",
        "облицовка",
        "навремено",
        "Штитник",
        "Наслов",
        "тост",
        "толерантни",
        "толеранција",
        "врв",
        "цврстина",
        "кула",
        "високи",
        "традиционален",
        "мирен",
        "спокојство",
        "трансцеденција",
        "трансцендентално",
        "патување",
        "богатство",
        "дрво",
        "неверојатно",
        "тренд",
        "трендовски",
        "притока",
        "почит",
        "триг",
        "триумф",
        "триумфално",
        "трофеј",
        "примирје",
        "ИСТИНА",
        "сигурен",
        "вистина",
        "вистинитост",
        "туторство",
        "учител",
        "близнак",
        "треперат",
        "на крајот",
        "судија",
        "едногласност",
        "едногласно",
        "непретенциозен",
        "непристрасен",
        "нераскинлива",
        "непрекинат",
        "неограничен",
        "подвлече",
        "разбирање",
        "преземи",
        "неподелена",
        "бесмртни",
        "недвосмислено",
        "се расплетува",
        "обединување",
        "рамномерно",
        "неинфицирани",
        "уникатен",
        "унисон",
        "унитарна",
        "обединета",
        "единство",
        "универзитет",
        "неограничено",
        "скромен",
        "несомнено",
        "несомнено",
        "несомнено",
        "неповреден",
        "несебичен",
        "ненадмината",
        "непоколеблива",
        "подигање",
        "исправен",
        "корисност",
        "голман",
        "обично",
        "алатка",
        "утописки",
        "одмор",
        "вакцина",
        "храбри",
        "NO TRANSLATION",
        "вредни",
        "авангарда",
        "победи",
        "кадифе",
        "бархатно",
        "преподобен",
        "почитување",
        "веродостојност",
        "зелен",
        "верификација",
        "потврдена",
        "навистина",
        "вистински",
        "верен",
        "верве",
        "ветеран",
        "викар",
        "победник",
        "победнички",
        "победа",
        "бдителност",
        "буден",
        "енергичност",
        "енергична",
        "селанец",
        "оправдано",
        "оправдување",
        "девица",
        "девственост",
        "доблест",
        "доблесни",
        "визија",
        "визионерски",
        "посетете",
        "посетител",
        "витално",
        "виталност",
        "весела",
        "живописни",
        "речник",
        "доброволец",
        "сладострасно",
        "гарантирам",
        "завет",
        "плати",
        "гаранција",
        "воин",
        "чувар",
        "будно",
        "чувар",
        "водоотпорен",
        "богатство",
        "водоотпорна",
        "поздрави",
        "бела",
        "белина",
        "здрава",
        "wicket",
        "широко распространета",
        "доброволно",
        "подготвеност",
        "неочекувани",
        "победник",
        "победа",
        "добивки",
        "безжичен",
        "wis",
        "мудрост",
        "мудар",
        "духовитост",
        "издржи",
        "wits",
        "духовит",
        "волшебник",
        "утроба",
        "прекрасно",
        "прекрасно",
        "чудесно",
        "збор",
        "работа",
        "обожување",
        "вреди",
        "достоен",
        "wot",
        "писател",
        "млад",
        "помлади",
        "младина",
        "ревност",
        "ревносен",
        "кора од лимон",
    ]
)

_negative = set(
    [
        "напушти",
        "напуштени",
        "напуштање",
        "киднапирање",
        "несоодветно",
        "аберација",
        "одвратам",
        "одвратни",
        "абјект",
        "абнормални",
        "укинување",
        "укинување",
        "одвратни",
        "мерзост",
        "прекине",
        "абортус",
        "неуспешен",
        "абразија",
        "укинување",
        "апсцес",
        "отсуство",
        "отсутен",
        "отсутен",
        "отсуство од работа",
        "апсурдно",
        "апсурдност",
        "злоупотреба",
        "бездна",
        "бездната",
        "несреќа",
        "случајно",
        "проклети",
        "обвинение",
        "акузативен",
        "обвинети",
        "обвинител",
        "обвинувајќи",
        "болка",
        "болки",
        "киселина",
        "актуелен",
        "седерот",
        "зависност",
        "маснотии",
        "судијата",
        "опомена",
        "бегам",
        "развратен",
        "прељуба",
        "противник",
        "негативни",
        "катастрофа",
        "вознемири",
        "погодени",
        "болка",
        "навреда",
        "се плаши",
        "последиците",
        "послевкус",
        "отежнат",
        "отежнувачки",
        "влошување",
        "агресија",
        "агресивен",
        "агресор",
        "вознемирен",
        "вознемирен",
        "агитација",
        "агонизирачки",
        "агонија",
        "агол",
        "ail",
        "болен",
        "бесцелно",
        "воздух",
        "аларм",
        "алармантно",
        "алкохолизам",
        "странец",
        "отуѓи",
        "отуѓен",
        "отуѓување",
        "алимент",
        "тврдење",
        "тврдат",
        "оддалечен",
        "раздразнување",
        "двосмислена",
        "заседа",
        "амнезија",
        "амфетамини",
        "anaconda",
        "анален",
        "анархизам",
        "анархист",
        "анархија",
        "анатема",
        "антички",
        "лутина",
        "ангина",
        "риболов",
        "лути",
        "болка",
        "непријателство",
        "анимус",
        "уништува",
        "уништен",
        "аннигилација",
        "нервирај",
        "вознемиреност",
        "досадни",
        "поништи",
        "поништување",
        "аномалија",
        "анонимен",
        "антагонизам",
        "антагонист",
        "антагонистички",
        "антракс",
        "антихрист",
        "антипатија",
        "застарена",
        "антисоцијален",
        "антитеза",
        "анксиозност",
        "нервозни",
        "apache",
        "апатичен",
        "апатија",
        "листопад",
        "ужасни",
        "апендицитис",
        "приведување",
        "загрижен",
        "присвојување",
        "архаичен",
        "напорно",
        "тврдат",
        "аргумент",
        "аргументативно",
        "суви",
        "вооружување",
        "arraignment",
        "долгови",
        "апсење",
        "ароганција",
        "арогантен",
        "арсен",
        "подметнување пожар",
        "артилерија",
        "пепел",
        "засрамен",
        "пепел",
        "газ",
        "нападам",
        "напаѓач",
        "атентатор",
        "атентат",
        "атентат",
        "напад",
        "кретену",
        "заблуди",
        "адстрингентно",
        "азил",
        "атеизам",
        "атеросклероза",
        "крволочен",
        "злосторство",
        "атрофија",
        "напад",
        "напад",
        "атенуирани",
        "слабеењето",
        "смелост",
        "строго",
        "штедење",
        "автократски",
        "аутопсија",
        "лавина",
        "страст",
        "Одмазднички",
        "аверс",
        "аверзија",
        "избегнувајте",
        "избегнување",
        "Ужасно",
        "непријатност",
        "криво",
        "ѓубре",
        "гугање",
        "бабун",
        "назад",
        "наназад",
        "подводна вода",
        "бактерија",
        "NO TRANSLATION",
        "лошо",
        "јазовец",
        "лошо",
        "лошо",
        "судски извршители",
        "мамка",
        "бала",
        "Бал",
        "NO TRANSLATION",
        "разбојник",
        "бен",
        "тресне",
        "бенџер",
        "прогони",
        "протерани",
        "протерување",
        "банкрот",
        "банкрот",
        "banshee",
        "бар",
        "варварски",
        "варварски",
        "варварство",
        "кората",
        "забрането",
        "неплодна",
        "барикада",
        "бариера",
        "неосновани",
        "копиле",
        "тесто",
        "погоди",
        "батерија",
        "битка",
        "се бореше",
        "бојното поле",
        "bawdy",
        "бајонет",
        "носител",
        "ѕвер",
        "тивко",
        "тепа",
        "се случило",
        "моли",
        "просјак",
        "молат",
        "бегемот",
        "овде",
        "задоцнета",
        "омаловажувај",
        "воинствена",
        "појас",
        "бендер",
        "ужалените",
        "жалост",
        "лишена",
        "бесрамно",
        "бестијален",
        "предавам",
        "предавство",
        "внимавајте",
        "збунет",
        "пристрасност",
        "пристрасно",
        "расправии",
        "NO TRANSLATION",
        "фанатик",
        "фатално",
        "жолчка",
        "биопсија",
        "бреза",
        "родно место",
        "кучка",
        "залак",
        "горко",
        "горчина",
        "бизарно",
        "црна",
        "блек џек",
        "уцена",
        "црнилото",
        "Вина",
        "нездраво",
        "богохулен",
        "богохулство",
        "експлозија",
        "бесрамно",
        "blather",
        "пожар",
        "мрачна",
        "крварење",
        "шкарт",
        "лошо влијание",
        "заблудени",
        "слеп",
        "заслепен",
        "слепо",
        "слепило",
        "блистер",
        "подуени",
        "дупка",
        "блокада",
        "крвопролевање",
        "жедните",
        "крвав",
        "размачкана",
        "вентилатор",
        "искра",
        "блуз",
        "блеф",
        "грешка",
        "заматено",
        "заматен",
        "руменило",
        "фали",
        "бомба",
        "лажен",
        "врие",
        "бојлер",
        "бомба",
        "бомбардирам",
        "бомбардирање",
        "бомбардиран",
        "ропство",
        "обврзници",
        "Boo",
        "тивок",
        "алкохол",
        "NO TRANSLATION",
        "здодевност",
        "здодевен",
        "заемопримачот",
        "пречи",
        "пречеше",
        "дното",
        "врзана",
        "рунда",
        "говеда",
        "момче",
        "бојкот",
        "Брег",
        "ракија",
        "бравадо",
        "тепачка",
        "безобразен",
        "прекршување",
        "се расипа",
        "безобразен",
        "NO TRANSLATION",
        "мито",
        "мито",
        "бригада",
        "сулфур",
        "наежвам",
        "широк",
        "петел",
        "скрши",
        "скршен",
        "бордел",
        "модринка",
        "тежок товар",
        "брутално",
        "бруталност",
        "брутален",
        "бифе",
        "бубачка",
        "NO TRANSLATION",
        "луковица",
        "силеџија",
        "скитам",
        "bummer",
        "оптоварен",
        "бирократија",
        "бирократ",
        "крадец",
        "кражба",
        "погреб",
        "погребан",
        "бурке",
        "изгорен",
        "разби",
        "Месар",
        "задник",
        "збунет",
        "кабала",
        "какофонија",
        "cad",
        "кадавер",
        "кафез",
        "пресметување",
        "NO TRANSLATION",
        "повици",
        "кампања",
        "откажете",
        "рак",
        "canker",
        "канибал",
        "канибализам",
        "NO TRANSLATION",
        "заробеник",
        "заробеништво",
        "каптор",
        "фаќање",
        "труп",
        "карцином",
        "кардиомиопатија",
        "негрижа",
        "карикатура",
        "кариес",
        "масакр",
        "телесна",
        "месојади",
        "картел",
        "случај",
        "ковчег",
        "каста",
        "жртва",
        "катаракта",
        "катастрофа",
        "катетер",
        "претпазливост",
        "отстапи",
        "гробишта",
        "цензор",
        "цензура",
        "наплата",
        "престанок",
        "шега",
        "шега",
        "разочарување",
        "предизвик",
        "хаос",
        "хаотичен",
        "шарада",
        "наплатлив",
        "потера",
        "казнување",
        "зборлив",
        "евтини",
        "измамник",
        "чизкејк",
        "шикан",
        "детски",
        "студено",
        "хлороформ",
        "задави",
        "колера",
        "сека",
        "скучна работа",
        "хроничен",
        "цигара",
        "врева",
        "судир",
        "судир",
        "ноктот",
        "манастир",
        "заматен",
        "облачност",
        "грмушка",
        "несмасен",
        "кокаин",
        "принудува",
        "принуда",
        "ковчегот",
        "студ",
        "студено",
        "студенило",
        "Чолиќ",
        "колапс",
        "судир",
        "заговор",
        "кома",
        "коматозен",
        "борба",
        "борбен",
        "борбена",
        "посветеност",
        "мешање",
        "комунизмот",
        "комунист",
        "конкуренција",
        "се жалат",
        "жалба",
        "комплексен",
        "комплексност",
        "комплицира",
        "комплицирано",
        "компликација",
        "компост",
        "принуда",
        "задолжително",
        "скрие",
        "сокриени",
        "прикривање",
        "суета",
        "замислен",
        "потрес на мозокот",
        "осуди",
        "осуда",
        "погрешно",
        "понижување",
        "исповед",
        "ограничи",
        "ограничени",
        "затвор",
        "конфискувам",
        "конфискација",
        "пожар",
        "конфликт",
        "конфликтни",
        "смутен",
        "збунет",
        "збуни",
        "конфузија",
        "метеж",
        "зашеметување",
        "освојување",
        "конспиратор",
        "конспирирам",
        "вчудоневиденост",
        "запек",
        "ограничи",
        "ограничени",
        "ограничување",
        "зараза",
        "заразно",
        "загадуваат",
        "контаминирани",
        "контаминација",
        "презир",
        "презир",
        "презир",
        "спорно",
        "шверц",
        "договор",
        "контрадикторни",
        "контрадикција",
        "контрадикторни",
        "напротив",
        "контрастен",
        "во спротивност",
        "контраверзија",
        "контроверзен",
        "контроверзии",
        "осуденик",
        "убедување",
        "coop",
        "копирај",
        "копирај",
        "коронер",
        "телесна",
        "труп",
        "корекција",
        "корозија",
        "корозивни",
        "корумпиран",
        "корумпиран",
        "корупција",
        "кашлица",
        "советник",
        "coursing",
        "пожелавам",
        "кукавица",
        "кукавичлук",
        "кукавички",
        "crabby",
        "пукнатина",
        "разбиена",
        "пукање",
        "грч",
        "тесна",
        "чудак",
        "чудно",
        "глупости",
        "несреќа",
        "ползи",
        "избрзани",
        "луд",
        "крцкање",
        "суштество",
        "лази",
        "криминал",
        "криминалец",
        "криминал",
        "работно време",
        "осакатена",
        "осакатена",
        "криза",
        "свежи",
        "критичар",
        "критики",
        "критикуваат",
        "дупка",
        "крстот",
        "свиткан",
        "круцијално",
        "распнување",
        "сурова",
        "сурово",
        "сурово",
        "суровост",
        "се распаѓа",
        "криза",
        "крстоносна војна",
        "смачкана",
        "дробење",
        "корка",
        "плаче",
        "плаче",
        "крипта",
        "рогоносец",
        "кукавица",
        "одберам",
        "вина",
        "виновен",
        "виновник",
        "култ",
        "тежок",
        "cupping",
        "cur",
        "проклетство",
        "проколнати",
        "пцуејќи",
        "површно",
        "машина",
        "cutthroat",
        "сечење",
        "цијанид",
        "циклон",
        "циста",
        "цитомегаловирус",
        "dabbling",
        "демон",
        "дафт",
        "нож",
        "штета",
        "штети",
        "проклето",
        "проклетство",
        "проклети",
        "амортизери",
        "првут",
        "леди",
        "опасност",
        "опасно",
        "Потемни",
        "затемнет",
        "темнина",
        "попарен",
        "лошо",
        "збунет",
        "деактивирај",
        "ќор-сокак",
        "смртоносна",
        "глуви",
        "смрт",
        "дебакл",
        "разврат",
        "остатоци",
        "долг",
        "должник",
        "распаѓање",
        "распаднати",
        "починатиот",
        "измама",
        "измамнички",
        "измами",
        "измамени",
        "залажувам",
        "измама",
        "измамен",
        "деклинација",
        "пад",
        "опаѓање",
        "распаѓање",
        "намалување",
        "декрет",
        "изнемоштени",
        "дери",
        "одземе",
        "клевета",
        "клеветнички",
        "стандардно",
        "пораз",
        "поразен",
        "дефект",
        "NO TRANSLATION",
        "дефектен",
        "беспомошни",
        "одложување",
        "пркос",
        "пркосен",
        "недостаток",
        "дефицит",
        "издлаби",
        "дефлација",
        "деформира",
        "деформирани",
        "деформитет",
        "измама",
        "непостоечки",
        "пркосат",
        "дегенерација",
        "дегенерира",
        "деградација",
        "деградира",
        "деградирачки",
        "одложување",
        "одложен",
        "штетни",
        "бришење",
        "деликвенција",
        "делинквент",
        "делириус",
        "делириум",
        "потоп",
        "заблуда",
        "делумно",
        "побарувачка",
        "барајќи",
        "деменција",
        "деменција",
        "смрт",
        "уривање",
        "уривање",
        "демонот",
        "демонски",
        "деморализирани",
        "негирање",
        "негираше",
        "се откаже",
        "откажување",
        "негира",
        "негирање",
        "отиде",
        "заминување",
        "зависност",
        "зависност",
        "непристоен",
        "огорчавам",
        "депортација",
        "депортација",
        "расипани",
        "изопаченост",
        "игнорирање",
        "амортизирана",
        "амортизација",
        "депресија",
        "депресија",
        "депресивно",
        "депресија",
        "депресивна",
        "лишување",
        "пореметени",
        "напуштен",
        "потсмев",
        "дерогација",
        "навредлив",
        "сквернавење",
        "пустината",
        "напуштени",
        "дезертерство",
        "престанете",
        "пустош",
        "очај",
        "очај",
        "очајни",
        "злобен",
        "NO TRANSLATION",
        "деспотичен",
        "деспотизам",
        "бедни",
        "уништени",
        "уништувач",
        "уништување",
        "уништување",
        "деструктивни",
        "одред",
        "притвор",
        "притвореник",
        "притвор",
        "се влошува",
        "влошена",
        "влошување",
        "одврати",
        "детонира",
        "ублажување",
        "штета",
        "штетно",
        "дерит",
        "уништи",
        "катастрофални",
        "уништување",
        "ѓавол",
        "ѓаволски",
        "опкружен",
        "деволуција",
        "проголта",
        "ѓаволски",
        "дијагноза",
        "diatribe",
        "диктатор",
        "диктаторски",
        "диктатура",
        "NO TRANSLATION",
        "тешкотии",
        "тешкотии",
        "дигресија",
        "трошни",
        "разредена",
        "се намалува",
        "намалена",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "нечистотија",
        "валкани",
        "попреченост",
        "оневозможи",
        "оневозможено",
        "незадоволен",
        "не се согласувам",
        "не се согласувам",
        "несогласување",
        "недозволено",
        "разочарај",
        "разочаран",
        "разочарувачки",
        "разочарување",
        "неодобрување",
        "одобри",
        "неодобрени",
        "неодобрување",
        "катастрофа",
        "катастрофално",
        "не верувај",
        "отфрла",
        "празнење",
        "дисциплина",
        "одрекувам",
        "дисколорација",
        "обезцветен",
        "непријатност",
        "исклучете го",
        "исклучен",
        "исклучување",
        "незадоволство",
        "прекинете",
        "дисконтинуитет",
        "раздор",
        "обесхрабри",
        "обесхрабрување",
        "дискредитира",
        "дискриминираат",
        "дискриминирачки",
        "дискриминација",
        "презир",
        "болест",
        "болен",
        "раздробен",
        "ослободување",
        "изобличено",
        "срам",
        "NO TRANSLATION",
        "срамно",
        "незадоволни",
        "одвратност",
        "одвратно",
        "обесхрабрени",
        "разочарување",
        "нечесен",
        "нечесност",
        "срамно",
        "разочарување",
        "дезинформација",
        "неискрен",
        "се распадне",
        "дезинтеграција",
        "незаинтересирани",
        "не им се допаѓаат",
        "не му се допаѓа",
        "дислоциран",
        "лош",
        "разочарување",
        "расчленување",
        "разрешување",
        "непослушност",
        "непослушен",
        "непослушни",
        "нарушување",
        "неуредно",
        "неорганизирано",
        "омаловажување",
        "омаловажувачки",
        "диспаритет",
        "непристрасен",
        "отфрли",
        "дисперзија",
        "измените",
        "незадоволен",
        "незадоволство",
        "отстранување",
        "отфрлен",
        "спор",
        "дисквалификација",
        "дисквалификуван",
        "дисквалификува",
        "непочитување",
        "игнорирани",
        "дискредитиран",
        "непочитување",
        "непочитување",
        "нарушување",
        "незадоволство",
        "раздор",
        "несогласување",
        "лоша услуга",
        "дисидент",
        "растворање",
        "дисонанца",
        "нервозни",
        "невкусно",
        "искривени",
        "дисторзија",
        "одвлекува внимание",
        "расеан",
        "оттргнува",
        "одвлекување",
        "вознемирен",
        "вознемиреност",
        "потресени",
        "вознемирувачки",
        "недоверба",
        "нарушување",
        "вознемирени",
        "исклучи",
        "напуштен",
        "дивергентни",
        "одземени",
        "одземање",
        "развод",
        "вртоглавица",
        "вртоглавица",
        "приклучен",
        "NO TRANSLATION",
        "урнатини",
        "dole",
        "NO TRANSLATION",
        "доминантна",
        "доминација",
        "магаре",
        "караница",
        "несреќа",
        "осудени на пропаст",
        "судниот ден",
        "сомнеж",
        "сомнително",
        "сомнеж",
        "туш",
        "шпекулација",
        "пропаст",
        "драп",
        "одводнување",
        "Повлекување",
        "страв",
        "страшна",
        "страшно",
        "тмурна",
        "пиење",
        "возбуда",
        "беспилотно летало",
        "овенати",
        "суша",
        "се удави",
        "поспаност",
        "тешка работа",
        "пијан",
        "пијанство",
        "сомнително",
        "досадна",
        "неми",
        "кукла",
        "депонии",
        "dun",
        "зандана",
        "будала",
        "дупличност",
        "принуда",
        "прашина",
        "џуџе",
        "умирање",
        "дизентерија",
        "земјотрес",
        "прислушување",
        "указ",
        "феминин",
        "егитички",
        "исклучително",
        "извади",
        "исфрлање",
        "елиминација",
        "неостварлив",
        "ослабен",
        "NO TRANSLATION",
        "срам",
        "непријатно",
        "срам",
        "проневера",
        "емболија",
        "вовлечени",
        "итен случај",
        "енклава",
        "загрозување",
        "оптоварување",
        "загрози",
        "загрозени",
        "ендемични",
        "непријател",
        "спроведување",
        "енигматично",
        "непријателство",
        "поробен",
        "поробена",
        "поробување",
        "заплеткано",
        "заплеткане",
        "утробата",
        "завидлив",
        "епидемија",
        "епилепсија",
        "искоренување",
        "искоренување",
        "избришете",
        "ерозија",
        "err",
        "згрешив",
        "непредвидливо",
        "ератум",
        "погрешно",
        "грешка",
        "еруптира",
        "ерупција",
        "ескалира",
        "избегнувај",
        "шпионажа",
        "отуѓен",
        "евтаназија",
        "евакуира",
        "евакуација",
        "избегнувај",
        "затајување",
        "иселат",
        "иселување",
        "зло",
        "влоши",
        "егзацербација",
        "строго",
        "претерувам",
        "претерани",
        "испитување",
        "огорченост",
        "ископување",
        "вишок",
        "акциза",
        "исклучени",
        "со исклучок на",
        "исклучување",
        "измет",
        "ужасно",
        "изговор",
        "извршување",
        "џелард",
        "издувни гасови",
        "исцрпени",
        "исцрпеност",
        "NO TRANSLATION",
        "егзил",
        "егзорцизам",
        "иселеник",
        "избркај",
        "трошоци",
        "трошоци",
        "истекува",
        "истечен",
        "појасна",
        "експлодираат",
        "експлозија",
        "експлозивни",
        "изложени",
        "експропријација",
        "протерување",
        "истребувајте",
        "истребување",
        "исчезнат",
        "изгаснат",
        "вонсудски",
        "екстремитет",
        "фабрикувам",
        "измислица",
        "бледеат",
        "фекалии",
        "неуспешно",
        "неуспех",
        "несвестица",
        "неверна",
        "лажни",
        "падне",
        "погрешно",
        "заблуда",
        "погрешно",
        "паѓа",
        "лошо",
        "лага",
        "лажно",
        "фалсификување",
        "фалсификуваат",
        "фалсификат",
        "двоумење",
        "глад",
        "фанатичен",
        "фарса",
        "фарсично",
        "постот",
        "масти",
        "фатално",
        "фаталност",
        "судбина",
        "замор",
        "замор",
        "масни",
        "грешка",
        "погрешни",
        "сјај",
        "страв",
        "страшно",
        "страшно",
        "страв",
        "фебрилни",
        "фекал",
        "измет",
        "надомест",
        "изнемоштени",
        "финиширан",
        "падна",
        "злосторник",
        "кривично дело",
        "ферментира",
        "жесток",
        "жестокост",
        "караница",
        "феудален",
        "феудализмот",
        "трескавица",
        "фијаско",
        "фиб",
        "непостојана",
        "фиктивни",
        "тежок",
        "жестока",
        "борба",
        "борба",
        "фибустер",
        "нечистотија",
        "гнасни",
        "огнено оружје",
        "се вклопува",
        "мрачен",
        "флекирано",
        "означување",
        "флагрантно",
        "шушка",
        "размавта",
        "надуеност",
        "важнича",
        "мааната",
        "болва",
        "NO TRANSLATION",
        "руно",
        "месести",
        "flinch",
        "каламбур",
        "флоп",
        "пробивам",
        "грип",
        "флуктуација",
        "непријател",
        "спречен",
        "глупост",
        "будала",
        "глупаво",
        "глупост",
        "сточна храна",
        "обид",
        "забрани",
        "забрана",
        "сила",
        "принудени",
        "насилно",
        "претчувство",
        "затвори",
        "отфрли",
        "странски",
        "странец",
        "предупреден",
        "се губи",
        "задржана",
        "одземање",
        "фалсификат",
        "заборави",
        "заборавено",
        "зафрлено",
        "безформален",
        "блудство",
        "остави",
        "напуштен",
        "фаул",
        "фрактура",
        "кревка",
        "слабост",
        "избезумено",
        "измама",
        "измамнички",
        "полн",
        "измама",
        "излитена",
        "чуден",
        "замрзнување",
        "френетичен",
        "жестоки",
        "бес",
        "секирај",
        "страв",
        "исплашат",
        "исплашен",
        "страшно",
        "фригиден",
        "несериозно",
        "смрзнатини",
        "пена",
        "намуртено",
        "намуртено",
        "бесплодни",
        "фрустрираат",
        "фрустрирани",
        "фрустрација",
        "празнина",
        "бегалец",
        "брани",
        "гас",
        "fuming",
        "габа",
        "фанк",
        "бесен",
        "фурор",
        "бес",
        "гужва",
        "претрупан",
        "безобразен",
        "бесмисленост",
        "габи",
        "gag",
        "жолчка",
        "бесилка",
        "коцка",
        "коцкар",
        "коцкање",
        "банда",
        "гаол",
        "јаз",
        "ѓубре",
        "Гариш",
        "гарнир",
        "гас",
        "гаснење",
        "NO TRANSLATION",
        "слаб",
        "Гент",
        "геријатриски",
        "ужасно",
        "гето",
        "сенишен",
        "глупост",
        "глацијален",
        "сјајот",
        "блескав",
        "glib",
        "мрак",
        "мрачен",
        "гламур",
        "презаситеност",
        "ненаситност",
        "gnome",
        "гоблин",
        "безбожно",
        "гонореја",
        "goo",
        "гор",
        "клисура",
        "горила",
        "Крвав",
        "озборувања",
        "кал",
        "гихт",
        "влада",
        "грабне",
        "фаќајќи",
        "решетки",
        "рендан",
        "хелиум",
        "гроб",
        "алчноста",
        "алчен",
        "граната",
        "тага",
        "поплака",
        "тагува",
        "тешки",
        "мрачни",
        "валкано",
        "грозно",
        "мелење",
        "грозно",
        "гризли",
        "стон",
        "NO TRANSLATION",
        "бруто",
        "гротескно",
        "втемелени",
        "неосновани",
        "режеш",
        "growling",
        "злоба",
        "нервозно",
        "ужасно",
        "груб",
        "поплака",
        "пргаво",
        "герила",
        "крие",
        "гилотина",
        "вина",
        "виновен",
        "маска",
        "галеб",
        "лековерни",
        "пиштол",
        "млаз",
        "збунувачки",
        "цигански",
        "хаг",
        "ослабен",
        "влакнести",
        "на половина пат",
        "халуцинација",
        "петел",
        "запирање",
        "попречуваат",
        "тетива",
        "хендикеп",
        "виси",
        "бесилка",
        "малтретирање",
        "предвесник",
        "појачан",
        "цврстина",
        "тешкотии",
        "блудница",
        "штета",
        "штетно",
        "ужасни",
        "Хари",
        "грубост",
        "хаш",
        "хашиш",
        "избрзани",
        "омраза",
        "омраза",
        "мразеше",
        "омраза",
        "шокантен",
        "прогонува",
        "прогонуван",
        "хаос",
        "опасност",
        "опасни",
        "магла",
        "главоболка",
        "главен",
        "слух",
        "послушност",
        "оган",
        "болка",
        "металоиди",
        "бездушен",
        "пагански",
        "во голема мера",
        "пета",
        "зголемена",
        "грозоморно",
        "пекол",
        "пеколен",
        "беспомошен",
        "беспомошност",
        "хеморагија",
        "хемороиди",
        "ерес",
        "еретик",
        "хермафродит",
        "хероин",
        "херпес",
        "херпесвирус",
        "двоумење",
        "скриени",
        "одвратен",
        "препреки",
        "пречка",
        "хипи",
        "Подсвиркване",
        "потсмев",
        "удри",
        "досега",
        "кошница",
        "рапав",
        "Гоја",
        "измама",
        "hobo",
        "свиња",
        "шупливи",
        "холокауст",
        "бездомници",
        "носталгија",
        "убиствени",
        "убиство",
        "хомосексуалност",
        "хауба",
        "зависник",
        "очај",
        "безнадежен",
        "безнадежност",
        "орда",
        "ужасно",
        "ужасно",
        "грозни",
        "ужасно",
        "ужаснат",
        "ужасно",
        "хорор",
        "ужаси",
        "заложник",
        "непријателски",
        "непријателства",
        "непријателство",
        "завива",
        "тежок",
        "humbug",
        "понижувај",
        "понижувачки",
        "понижување",
        "хуман",
        "гладни",
        "ловец",
        "лов",
        "ураган",
        "побрза",
        "боли",
        "штетен",
        "боли",
        "hustler",
        "хидра",
        "хидроцефалус",
        "возбуда",
        "хипербола",
        "лицемерие",
        "лицемер",
        "лицемерно",
        "хистерија",
        "хистерична",
        "идиотизам",
        "идиот",
        "идиотски",
        "празен",
        "идолопоклонство",
        "незнаење",
        "неуки",
        "игнорирај",
        "лошо",
        "нелегално",
        "незаконитост",
        "нечитлив",
        "нелегитимен",
        "незаконски",
        "неписмени",
        "болест",
        "нелогично",
        "илузија",
        "имитирани",
        "имитација",
        "незрело",
        "незрелост",
        "неморално",
        "неморал",
        "непар",
        "оштетување",
        "непрооден",
        "нетрпеливост",
        "нетрпелив",
        "импич",
        "отповикување",
        "пречка",
        "несовршеност",
        "несовршено",
        "имитираат",
        "имитација",
        "неумолива",
        "имплицираат",
        "неволја",
        "наметнување",
        "невозможно",
        "импотенција",
        "импотентен",
        "запленета",
        "непрактично",
        "затвор",
        "затворен",
        "затвор",
        "несоодветност",
        "неразумно",
        "нечисто",
        "нечистотија",
        "импутација",
        "неспособност",
        "недостапни",
        "неточни",
        "неактивност",
        "неактивност",
        "NO TRANSLATION",
        "несоодветни",
        "неприфатливо",
        "неан",
        "неприменлив",
        "несоодветно",
        "невнимание",
        "нечујни",
        "непроценливо",
        "неспособност",
        "затворање",
        "во случај",
        "запален",
        "темјан",
        "непрестајна",
        "инцест",
        "инцестуозен",
        "инсинерација",
        "поттикнување",
        "небрежност",
        "некохерентни",
        "некомпатибилни",
        "некомпетентност",
        "неспособни",
        "некомплетност",
        "неразбирливо",
        "несоодветно",
        "несуштински",
        "невнимателен",
        "неконзистентност",
        "незгодно",
        "погрешно",
        "неверодостојни",
        "инкриминација",
        "инкубус",
        "направам",
        "неизлечива",
        "упад",
        "непристојни",
        "неодлучноста",
        "неодлучен",
        "неоправдано",
        "обештетување",
        "indenture",
        "неопределено",
        "обвинение",
        "обвинение",
        "рамнодушност",
        "сиромашен",
        "огорчен",
        "индигнација",
        "неопределен",
        "индоктринација",
        "дрско",
        "неефикасни",
        "неефективно",
        "неефикасност",
        "неефикасен",
        "нервозен",
        "непостојаност",
        "нееднаквост",
        "нееднакво",
        "инертен",
        "неоправдано",
        "NO TRANSLATION",
        "неискусни",
        "необјаснив",
        "озлогласен",
        "срам",
        "инфантицид",
        "инфантилен",
        "инфаркт",
        "зарази",
        "инфекција",
        "заразен",
        "инфериорен",
        "инфериорност",
        "пекол",
        "неплодност",
        "наезда",
        "неверник",
        "неверство",
        "немоќен",
        "немоќ",
        "воспаление",
        "надуени",
        "инфлација",
        "нанесете",
        "нанесување",
        "инфлуенца",
        "информатор",
        "прекршок",
        "ретко",
        "повреда",
        "инхибираат",
        "непријатни",
        "нечовечно",
        "нечовечност",
        "неповреден",
        "беззаконие",
        "забрана",
        "повредите",
        "повреден",
        "штетни",
        "повреда",
        "неправда",
        "затвореник",
        "неоперативна",
        "лудо",
        "лудило",
        "несигурен",
        "несигурност",
        "подмолно",
        "безначајност",
        "незначителен",
        "невидливи",
        "дрско",
        "несолвентност",
        "несолвентен",
        "нестабилност",
        "поттикнете",
        "поттикнување",
        "инсуфициенција",
        "недоволно",
        "недоволно",
        "навреда",
        "навреда",
        "бунтовник",
        "непремостлив",
        "востание",
        "inter",
        "забрана",
        "мешање",
        "интервенција",
        "прекинеш",
        "прекината",
        "неочекувано",
        "заплаши",
        "заплашување",
        "неподносливо",
        "нетолеранција",
        "нетолерантен",
        "затруени",
        "неподнослива",
        "интрига",
        "натрапник",
        "упад",
        "наметлива",
        "нападне",
        "напаѓач",
        "поништи",
        "поништување",
        "невалидност",
        "инвазија",
        "принудно",
        "инволуција",
        "гневен",
        "NO TRANSLATION",
        "пегли",
        "ирационален",
        "ирационалност",
        "непомирлив",
        "нередовно",
        "неправилност",
        "неважно",
        "непоправлив",
        "неодговорно",
        "непочтителен",
        "неотповиклива",
        "раздразливост",
        "нервозни",
        "иритирачки",
        "иритација",
        "изолиран",
        "изолација",
        "jabber",
        "затвор",
        "жаргон",
        "jarring",
        "жолтица",
        "љубоморен",
        "љубомора",
        "загрози",
        "опасност",
        "Џон",
        "шега",
        "NO TRANSLATION",
        "скокање",
        "ѓубре",
        "хунта",
        "малолетничка",
        "kern",
        "удар",
        "киднапирање",
        "убиј",
        "убиство",
        "змеј",
        "knell",
        "јазли",
        "работел",
        "макотрпна",
        "лавиринт",
        "недостаток",
        "недостасува",
        "безвреден",
        "натоварен",
        "заостануваат",
        "заостанува",
        "кошара",
        "жалење",
        "лизгање на земјиштето",
        "апатичен",
        "скапвам",
        "полнење",
        "пропаѓаат",
        "краде",
        "камшик",
        "доцна",
        "доцна",
        "латентен",
        "тоалети",
        "смешен",
        "лава",
        "беззаконие",
        "тужба",
        "адвокат",
        "лабави",
        "лаксатив",
        "мрзливи",
        "излегуваат во јавноста",
        "истекување",
        "спукан",
        "Остави",
        "пијавица",
        "пијавици",
        "NO TRANSLATION",
        "лимон",
        "лепра",
        "лезбејка",
        "намалува",
        "помалку",
        "смртоносна",
        "летаргија",
        "леукемија",
        "цената",
        "непријателство",
        "врски",
        "лажго",
        "клевета",
        "лижат",
        "лага",
        "безживотно",
        "ограничен",
        "лап",
        "lint",
        "алкохол",
        "бескрајни",
        "парничар",
        "litigate",
        "судски постапки",
        "парничен",
        "легло",
        "бледо",
        "леб",
        "лопатка",
        "NO TRANSLATION",
        "лути",
        "омраза",
        "омразен",
        "лобист",
        "NO TRANSLATION",
        "скакулците",
        "возвишени",
        "осаменост",
        "осамен",
        "осамен",
        "Loo",
        "разбој",
        "loon",
        "глупав",
        "плен",
        "изгуби",
        "губење",
        "загуба",
        "изгубени",
        "гласност",
        "дневна",
        "вулкан",
        "пониско",
        "спуштање",
        "најниска",
        "низини",
        "смирено",
        "смешен",
        "дремка",
        "грутка",
        "трнлив",
        "лудило",
        "лудак",
        "цедило",
        "наведуваш",
        "луд",
        "демне",
        "демнат",
        "бујна",
        "страст",
        "похотливо",
        "лажење",
        "Линч",
        "жезло",
        "луд",
        "луд",
        "лудак",
        "лудило",
        "мафија",
        "магнет",
        "импровизирани",
        "болест",
        "малаксаност",
        "маларија",
        "злонамерни",
        "злоупотреба на службената должност",
        "малформации",
        "злоба",
        "злонамерни",
        "малигни",
        "малигнитет",
        "малигни",
        "небрежност",
        "мандамус",
        "NO TRANSLATION",
        "магли",
        "манија",
        "манијак",
        "манијакално",
        "манипулира",
        "манипулација",
        "убиство без насилство",
        "ѓубриво",
        "mar",
        "маргина",
        "канелени",
        "martingale",
        "маченик",
        "мачеништво",
        "мазохизам",
        "масакр",
        "материјализам",
        "материјалист",
        "меандрирање",
        "бесмислено",
        "мали сипаници",
        "мешање",
        "медиокритет",
        "просечност",
        "меланхоличен",
        "меланхолија",
        "меле",
        "мелодрама",
        "колапс",
        "закана",
        "заканувачки",
        "Менен",
        "платеник",
        "безмилосно",
        "хаос",
        "неуредна",
        "метастази",
        "метанол",
        "мувла",
        "милиција",
        "мимикрија",
        "минимизирај",
        "минимум",
        "малцинство",
        "NO TRANSLATION",
        "погрешно однесување",
        "спонтан абортус",
        "зло",
        "немирна",
        "заблуда",
        "несоодветно однесување",
        "мизерни",
        "очајно",
        "мизерија",
        "несреќа",
        "заведени",
        "несреќа",
        "погрешно толкување",
        "заблуда",
        "погрешно",
        "лошо управување",
        "Несогласување",
        "погрешно",
        "погрешно",
        "неоправдан",
        "погрешно претставување",
        "погрешно толкување",
        "погрешно претставен",
        "исчезнати",
        "погрешно прикажување",
        "грешка",
        "погрешно",
        "љубовница",
        "NO TRANSLATION",
        "погрешно разбере",
        "недоразбирање",
        "злоупотреба",
        "Мите",
        "моб",
        "исмејување",
        "потсмевање",
        "малтретирање",
        "монохроматски",
        "монопол",
        "монсун",
        "чудовиште",
        "монструозност",
        "нерасположено",
        "симулација",
        "Морбидно",
        "морбидитет",
        "мртовечницата",
        "уморни",
        "морон",
        "мороничен",
        "залак",
        "смртен",
        "смртност",
        "мотивирање",
        "мртовечница",
        "комарец",
        "тагувај",
        "тажен",
        "жалост",
        "млеко",
        "кал",
        "вечната",
        "заблуден",
        "калливи",
        "муф",
        "мазга",
        "мајка",
        "се мрмори",
        "заушки",
        "убиство",
        "убиец",
        "убиствен",
        "мрачен",
        "NO TRANSLATION",
        "небесен",
        "мутант",
        "осакатени",
        "осакатување",
        "бунт",
        "NO TRANSLATION",
        "муцка",
        "миопија",
        "nab",
        "nadir",
        "NO TRANSLATION",
        "наивен",
        "безимени",
        "пелена",
        "наркотични",
        "гаден",
        "непослушен",
        "гадење",
        "гаден",
        "NO TRANSLATION",
        "потребен",
        "сиромашни",
        "злобни",
        "негација",
        "негативно",
        "занемарување",
        "запоставени",
        "занемарување",
        "небрежност",
        "несовесни",
        "NO TRANSLATION",
        "негро",
        "непотизам",
        "нервозен",
        "ниско",
        "коприва",
        "невралгија",
        "невроза",
        "невротичен",
        "никотин",
        "црнец",
        "кошмар",
        "нихилизам",
        "бучава",
        "бучна",
        "NO TRANSLATION",
        "глупости",
        "бесмислено",
        "јамка",
        "ништожност",
        "штетен",
        "непријатност",
        "NO TRANSLATION",
        "поништи",
        "вкочанет",
        "вкочанетост",
        "NO TRANSLATION",
        "оф",
        "дебели",
        "дебелина",
        "obi",
        "obit",
        "некролог",
        "приговор",
        "непристоен",
        "обврзува",
        "должник",
        "Бришење",
        "избришани",
        "облитерација",
        "заборавот",
        "ништожно",
        "непристојни",
        "непристојност",
        "опскурност",
        "пречка",
        "тврдоглави",
        "опструирај",
        "опструкција",
        "опструктивна",
        "тутун",
        "окултен",
        "чудак",
        "омразен",
        "мирис",
        "навреди",
        "навреден",
        "сторителот",
        "прекршок",
        "офанзива",
        "офанд",
        "офанзива",
        "ogre",
        "миризливи",
        "олигархија",
        "знак",
        "застрашувачки",
        "пропушти",
        "тежок",
        "onus",
        "истекува",
        "непроѕирно",
        "оперски",
        "опиат",
        "оценет",
        "опиум",
        "противник",
        "се спротивставуваат",
        "наспроти",
        "опозиција",
        "угнетување",
        "угнетување",
        "угнетувачки",
        "угнетувач",
        "orc",
        "тешко искушение",
        "Убиство",
        "сираче",
        "наводно",
        "исфрли",
        "надвор",
        "негодување",
        "куќа",
        "чуден",
        "одметник",
        "бес",
        "овации",
        "арогантен",
        "overburden",
        "облачно",
        "претерано",
        "предозирање",
        "задоцнета",
        "преценето",
        "прелевање",
        "обрасната",
        "преоптоварување",
        "преплатено",
        "надмоќ",
        "надмоќна",
        "прескапата",
        "надзор",
        "соборување",
        "превртување",
        "победи",
        "совладан",
        "поради тоа",
        "оксидација",
        "болка",
        "огорчен",
        "болно",
        "болно",
        "болки",
        "парализа",
        "пандемија",
        "NO TRANSLATION",
        "паника",
        "парализа",
        "парализиран",
        "параноја",
        "паразит",
        "NO TRANSLATION",
        "папагал",
        "парсимони",
        "партиски",
        "NO TRANSLATION",
        "пасивно",
        "пасивност",
        "лепенка",
        "патетично",
        "покровител",
        "NO TRANSLATION",
        "мало",
        "пауер",
        "пион",
        "созревање",
        "плаќање",
        "особености",
        "пешачки",
        "казнено",
        "казна",
        "пенетрација",
        "казнено-поправниот дом",
        "погибел",
        "опасност",
        "опасен",
        "загине",
        "расипливи",
        "исчезна",
        "губење",
        "вероломство",
        "пернициозен",
        "сторител",
        "овековечување",
        "збунет",
        "збунетост",
        "прогони",
        "прогон",
        "пертурбација",
        "пертусис",
        "перверзни",
        "перверзија",
        "Перверзен",
        "изобличено",
        "песимизам",
        "песимист",
        "штетник",
        "помор",
        "миленик",
        "ситни",
        "фантом",
        "флегма",
        "лажни",
        "спасување",
        "пикетирање",
        "марината",
        "свиња",
        "гулаб",
        "купови",
        "грабеж",
        "макро",
        "плима",
        "бор",
        "зглоб",
        "пик",
        "пиратерија",
        "пират",
        "пиштол",
        "замка",
        "плагијат",
        "чума",
        "тужителот",
        "позлатен",
        "играч",
        "молба",
        "мака",
        "омраза",
        "опаѓа",
        "грабеж",
        "се фрлам",
        "пневмонија",
        "ловење",
        "бесмислено",
        "отров",
        "отруен",
        "труење",
        "отровен",
        "ѕиркаат",
        "полемична",
        "полио",
        "загадуваат",
        "загадување",
        "полигамијата",
        "Помпа",
        "помпезно",
        "тежок",
        "лошо",
        "поп",
        "боцкаво прасе",
        "порно",
        "порно",
        "порнографски",
        "порнографија",
        "позираат",
        "поседува",
        "поседување",
        "постхумно",
        "одложување",
        "фунта",
        "сиромаштија",
        "немоќен",
        "шега",
        "несигурни",
        "предел",
        "граблив",
        "ситуација",
        "бременост",
        "предрасуда",
        "предрасуди",
        "предрасуди",
        "предумисла",
        "притисок",
        "претенциозно",
        "се преправам",
        "преправаше",
        "преправајќи се",
        "изговор",
        "претензии",
        "превентивна",
        "плен",
        "измамник",
        "бодлив",
        "затвор",
        "затвореник",
        "привидна",
        "проблем",
        "одлагање",
        "одложување",
        "профана",
        "вулгарност",
        "изобилство",
        "забрането",
        "забрана",
        "Продолжи",
        "промискуитетен",
        "пропаганда",
        "гонење",
        "гонење",
        "проститутка",
        "проституција",
        "провокација",
        "предизвикувајќи",
        "СРЈ",
        "љубопитност",
        "психоза",
        "публицист",
        "подуени",
        "удар",
        "луто",
        "казни",
        "казнет",
        "казнување",
        "казна",
        "казнени",
        "чистилиште",
        "чистка",
        "гној",
        "шаркане",
        "бајка",
        "пепел",
        "квандаријат",
        "караница",
        "quash",
        "quell",
        "сомнително",
        "quicksilver",
        "престанам",
        "треперат",
        "треперејќи",
        "квиз",
        "раб",
        "бесни",
        "беснило",
        "решетка",
        "рекет",
        "радијација",
        "радиоактивен",
        "радон",
        "бес",
        "беснее",
        "партали",
        "рација",
        "железнички",
        "овен",
        "бескорисно",
        "дивеење",
        "скардни",
        "откуп",
        "силување",
        "раптори",
        "rascal",
        "осип",
        "стаорец",
        "рејтинг",
        "груб",
        "ладен",
        "бесно",
        "реакционерни",
        "заден",
        "бунтовник",
        "укор",
        "побитни",
        "непослушен",
        "рецесија",
        "рецидивизам",
        "невнимателен",
        "непромисленост",
        "излишни",
        "рефлукс",
        "огноотпорни",
        "одбивање",
        "одбие",
        "одби",
        "регрес",
        "регресија",
        "жалам",
        "за жал",
        "жали",
        "жалење",
        "регулаторен",
        "заузда",
        "отфрли",
        "одбиен",
        "одбивање",
        "отфрла",
        "рецидив",
        "испаѓање",
        "откажете се",
        "неподготвени",
        "притвор",
        "помошен",
        "незнам",
        "каење",
        "отстранување",
        "отстрани",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "отпадник",
        "се откажат",
        "одрекување",
        "NO TRANSLATION",
        "отвратителен",
        "отфрлање",
        "репресија",
        "репресија",
        "опомена",
        "препечатување",
        "одмазда",
        "срам",
        "република",
        "отфрлање",
        "одбивност",
        "престанам",
        "ресесија",
        "навредува",
        "огорчен",
        "незадоволство",
        "поднесе оставка",
        "оставка",
        "поднесе оставка",
        "се спротивстави",
        "отпор",
        "отпорни",
        "отпор",
        "воздржи",
        "ограничи",
        "ограничување",
        "рестриктивни",
        "одмазди",
        "одмазда",
        "одмазднички",
        "ретардиран",
        "ретардација",
        "резистентен",
        "возврати",
        "повлече",
        "повлекување",
        "намалување",
        "одмазда",
        "ретроградна",
        "одмазда",
        "пресврт",
        "отповикување",
        "одземе",
        "револт",
        "револт",
        "револвер",
        "одвратност",
        "ревматизам",
        "нервозни",
        "испрекинат",
        "потсмев",
        "смешно",
        "полн",
        "пушка",
        "расцеп",
        "крути",
        "ригидност",
        "строгост",
        "ригорозни",
        "ѕвонче",
        "немири",
        "немири",
        "ризик",
        "ризично",
        "ривалство",
        "Роб",
        "крадец",
        "кражба",
        "непријателски",
        "лаж",
        "гниење",
        "гнили",
        "грубост",
        "NO TRANSLATION",
        "ред",
        "хулиган",
        "ѓубре",
        "урнатини",
        "rue",
        "возбуда",
        "солиден",
        "уништи",
        "руиниран",
        "руини",
        "гласини",
        "бега",
        "руптура",
        "NO TRANSLATION",
        "рѓа",
        "рѓосан",
        "безмилосен",
        "NO TRANSLATION",
        "саботажа",
        "жртви",
        "за жал",
        "тага",
        "sag",
        "SAP",
        "сарказам",
        "сарком",
        "сардоничен",
        "сатански",
        "заситен",
        "дивјак",
        "дивјаштво",
        "краста",
        "скеле",
        "скалпел",
        "лушпеста",
        "скандал",
        "скандалозно",
        "скудни",
        "жртвено јагне",
        "лузна",
        "ретки",
        "едвај",
        "недостаток",
        "плашиш",
        "чистач",
        "шема",
        "раскол",
        "шизофренија",
        "ишијас",
        "потсмев",
        "караница",
        "прекршување",
        "врел",
        "презир",
        "скорпија",
        "Скот",
        "измамник",
        "зло",
        "борејќи се",
        "скрепи",
        "крик",
        "вреска",
        "крик",
        "зезнав",
        "штрек",
        "чистење",
        "прегледај",
        "надзор",
        "ѓубре",
        "искаса",
        "отцепување",
        "затскриено",
        "NO TRANSLATION",
        "секреција",
        "таинствена",
        "секташки",
        "побуна",
        "заведе",
        "заведување",
        "сегрегира",
        "сегрегирани",
        "заплени",
        "себични",
        "себичност",
        "сенилен",
        "бесмислено",
        "реченица",
        "сепаратистички",
        "сепса",
        "септички",
        "секвестрација",
        "спокоен",
        "змија",
        "слуга",
        "служат",
        "сервилен",
        "службеност",
        "неуспех",
        "одмор",
        "канализација",
        "канализација",
        "излитена",
        "колиба",
        "кал",
        "сенки",
        "тресење",
        "несигурен",
        "срам",
        "се гади",
        "срам",
        "срамно",
        "бесрамно",
        "Шангај",
        "ајкула",
        "распарчи",
        "разнишани",
        "барака",
        "школка",
        "shelved",
        "бродолом",
        "срање",
        "се тресат",
        "шок",
        "лошо",
        "пука",
        "снимање",
        "shoplifting",
        "недостаток",
        "недостаток",
        "shot",
        "бутам",
        "showy",
        "крик",
        "писклив",
        "се намалува",
        "се намали",
        "се згрози",
        "избегнувај",
        "болен",
        "болен",
        "болен",
        "болест",
        "глупо",
        "NO TRANSLATION",
        "грешен",
        "злобна",
        "грешник",
        "греши",
        "сирена",
        "малечка",
        "скептичен",
        "скептичен",
        "искривена",
        "пропадна",
        "прескокнете",
        "престрелка",
        "гасена",
        "згура",
        "слем",
        "клевета",
        "клевета",
        "шлаканица",
        "колење",
        "кланица",
        "колење",
        "роб",
        "ропство",
        "убие",
        "убиец",
        "лапавица",
        "лигави",
        "slink",
        "се лизга",
        "NO TRANSLATION",
        "невешт",
        "мрзлив",
        "slouch",
        "блато",
        "бавноста",
        "тиња",
        "голтка",
        "слаб",
        "сиромашни",
        "рецесија",
        "slur",
        "каша",
        "курва",
        "итар",
        "мирис",
        "мал",
        "пресече",
        "разбиени",
        "мешање",
        "мирис",
        "мириса",
        "смрток",
        "порази",
        "пушач",
        "задуши",
        "дамка",
        "самодоволен",
        "шверцува",
        "шверцер",
        "шверц",
        "смрдеа",
        "финтата",
        "прекршоци",
        "змија",
        "примка",
        "огорчено",
        "рбет",
        "искористиш приликата",
        "неизразен",
        "потсмев",
        "кивавица",
        "снајде",
        "сноб",
        "натопете",
        "NO TRANSLATION",
        "социјалистички",
        "почва",
        "извалкан",
        "соматски",
        "мрачен",
        "саѓи",
        "магии",
        "нервозен",
        "болно",
        "болно",
        "болка",
        "тага",
        "тажен",
        "NO TRANSLATION",
        "бездушен",
        "соученик",
        "кисело",
        "плескам",
        "спазам",
        "плукаат",
        "копје",
        "дамка",
        "спектар",
        "спектрален",
        "шпекулации",
        "потрошени",
        "spinster",
        "инает",
        "зајадлив",
        "отскокнување",
        "подели",
        "разделување",
        "расипат",
        "спојлер",
        "зборуваше",
        "сунѓер",
        "преплаши",
        "испрснува",
        "треска",
        "спрат",
        "лажен",
        "шкарт",
        "сквотер",
        "извивам",
        "squelch",
        "извивам",
        "прободе",
        "запрепастувачки",
        "стагнација",
        "дамка",
        "застоена",
        "следи",
        "ќор-сокак",
        "застој",
        "загледан",
        "остар",
        "вчудоневиди",
        "глад",
        "гладуваше",
        "гладува",
        "стационарно",
        "предавам",
        "крадат",
        "крадење",
        "тајно",
        "стереотип",
        "стереотипни",
        "стерилен",
        "стерилитет",
        "строг",
        "беспомошна",
        "вкочанетост",
        "задуши",
        "задушено",
        "стигмата",
        "мртвородено",
        "Стинг",
        "боцкање",
        "скржавиот",
        "смрдеа",
        "смрдлив",
        "престој",
        "акции",
        "украден",
        "камен",
        "каменувани",
        "столици",
        "застанување",
        "бура",
        "бурна",
        "затегнати",
        "тесно",
        "заробени",
        "странец",
        "задуши",
        "скитници",
        "стрес",
        "расправии",
        "штрајк",
        "лента",
        "лента",
        "одземени",
        "удар",
        "борба",
        "стомак",
        "затнат",
        "се сопнуваат",
        "шокиран",
        "заостануваат",
        "глупав",
        "глупост",
        "ступор",
        "шпион",
        "покори",
        "предмет",
        "подложен",
        "подложување",
        "потчинување",
        "подредени",
        "судски налог",
        "слегнување",
        "субвенција",
        "преживее",
        "одземе",
        "субверзија",
        "субверзивен",
        "погубвам",
        "подлегнува",
        "цица",
        "морон",
        "тужи",
        "страдаат",
        "страдалец",
        "страдање",
        "задушувачки",
        "задушување",
        "самоубиство",
        "самоубиство",
        "задушен",
        "покана",
        "потонат",
        "површни",
        "излишно",
        "суеверна",
        "сузбивање",
        "потиснување",
        "доплата",
        "Груб",
        "предавање",
        "предавање",
        "подложни",
        "сомнителен",
        "суспензија",
        "сомневање",
        "сомнителен",
        "брис",
        "мочуриште",
        "мочуриште",
        "свастика",
        "оток",
        "swig",
        "свински",
        "потечени",
        "симптом",
        "синкопа",
        "табу",
        "нечистотија",
        "NO TRANSLATION",
        "заплеткано",
        "доцнење",
        "оздола",
        "тарифа",
        "оцрни",
        "остани",
        "без вкус",
        "потсмев",
        "данок",
        "закачам",
        "надразнување",
        "досадни",
        "NO TRANSLATION",
        "бура",
        "искушение",
        "tenement",
        "терминал",
        "престанок",
        "термит",
        "страшно",
        "терор",
        "тероризам",
        "терористички",
        "тероризирам",
        "тетанус",
        "tether",
        "кражба",
        "теизмот",
        "теократска",
        "крадец",
        "жеден",
        "трн",
        "трнлив",
        "безмислено",
        "ѓубре",
        "закана",
        "се закануваат",
        "заканувачки",
        "thresh",
        "удар",
        "гас",
        "криминалец",
        "удар",
        "гром",
        "спречи",
        "tiff",
        "срамежливи",
        "плашливост",
        "совети",
        "тирада",
        "уморен",
        "замор",
        "заморен",
        "тит",
        "жаба",
        "тутун",
        "тоалет",
        "тегови",
        "толерира",
        "забоболка",
        "маки",
        "искинати",
        "торпедо",
        "торрид",
        "измама",
        "тивко",
        "мачење",
        "допре",
        "досаден",
        "тешко",
        "токсични",
        "токсин",
        "трагедија",
        "трагично",
        "предавник",
        "трамп",
        "транс",
        "престап",
        "орнаменти",
        "стапици",
        "ѓубре",
        "ѓубре",
        "трауматски",
        "NO TRANSLATION",
        "травестија",
        "предавничка",
        "предавство",
        "предавство",
        "трепет",
        "тремор",
        "нервоза",
        "злосторство",
        "неволја",
        "трибунал",
        "трик",
        "измама",
        "Ситница",
        "трипал",
        "трол",
        "проблематично",
        "труба",
        "сушење",
        "тумор",
        "тумор",
        "метеж",
        "бурни",
        "турбуленција",
        "турбулентен",
        "превирања",
        "грч",
        "тајфун",
        "тирански",
        "тиранија",
        "тиранин",
        "грдотија",
        "грдо",
        "чир",
        "еднтер",
        "ултиматум",
        "не може",
        "неприфатливо",
        "неопределен",
        "неодобрени",
        "неприкосновен",
        "недостижно",
        "непривлечна",
        "неовластено",
        "неизбежни",
        "несвесно",
        "неподнослива",
        "неверување",
        "неверојатно",
        "неродени",
        "чуден",
        "нерешителност",
        "неизвесно",
        "непроменлив",
        "нечист",
        "непријатно",
        "несвесно",
        "несвесен",
        "неуставен",
        "неконтролирано",
        "неконтролирано",
        "неопределени",
        "поткопана",
        "недоволно платени",
        "подредени",
        "непожелни",
        "несакани",
        "вратите",
        "нелагодност",
        "непријатно",
        "необразован",
        "невработен",
        "нееднаков",
        "нерамномерно",
        "необјаснето",
        "нефер",
        "неправедност",
        "неверен",
        "неповолно",
        "недовршени",
        "Непростлив",
        "несреќно",
        "непријателски",
        "неисполнет",
        "без мебел",
        "безбожнички",
        "неблагодарна",
        "несреќа",
        "несреќни",
        "нездраво",
        "несреќен",
        "неважно",
        "неопределен",
        "неоправдано",
        "неинформирани",
        "непосветен",
        "неинспириран",
        "неразбирливо",
        "ненамерно",
        "незаинтересирани",
        "неинтересен",
        "неправеден",
        "неоправдано",
        "неоправдано",
        "нељубезен",
        "непознат",
        "незаконско",
        "нелиценциран",
        "несреќен",
        "неуправа",
        "неприродно",
        "неофицијален",
        "неплатено",
        "непријатно",
        "непопуларен",
        "непредвидливо",
        "неподготвени",
        "непродуктивни",
        "непрофитабилен",
        "незаштитени",
        "необјавени",
        "несигурен",
        "невработени",
        "непослушен",
        "небезбедно",
        "незадоволително",
        "незадоволни",
        "непристојни",
        "бескрупулозните",
        "несмирен",
        "непристоен",
        "несофистицирани",
        "неописливо",
        "нестабилен",
        "неуспешни",
        "несоодветни",
        "unsung",
        "неподдржан",
        "неодржлив",
        "несимпатичен",
        "нескротлив",
        "неодржлива",
        "незамисливо",
        "неуреден",
        "ненавремено",
        "без наслов",
        "нераскажано",
        "незгодно",
        "необучен",
        "невистинити",
        "неверодостојно",
        "неоправдан",
        "неизмиени",
        "несакана",
        "добро",
        "неподготвеност",
        "неразумно",
        "невешт",
        "недостоен",
        "непопустливи",
        "пресврт",
        "востание",
        "вознемирување",
        "вознемирен",
        "урхин",
        "итно",
        "бескорисни",
        "usurp",
        "узурпиран",
        "камата",
        "Конкурс",
        "празен",
        "нејасни",
        "нејасност",
        "залудно",
        "вампир",
        "исчезна",
        "суета",
        "варичела",
        "варикоза",
        "вегетативна",
        "жестоко",
        "одмазда",
        "одмазда",
        "Одмазднички",
        "отров",
        "отровно",
        "бременост",
        "работ",
        "штетници",
        "против",
        "вртоглавица",
        "вето",
        "заменик",
        "злобни",
        "жртва",
        "жртва",
        "негативец",
        "злобно",
        "кривичен",
        "повреда",
        "насилство",
        "насилни",
        "насилно",
        "Viper",
        "вирулентност",
        "вирус",
        "посета",
        "vixen",
        "нестабилност",
        "вулкан",
        "повраќање",
        "вуду",
        "вулгарен",
        "вулгарност",
        "ранливост",
        "мршојадец",
        "вафли",
        "плачете",
        "почекај",
        "валоа",
        "NO TRANSLATION",
        "бледнее",
        "сакајќи",
        "војна",
        "управник",
        "ware",
        "војување",
        "воинствен",
        "предупреди",
        "искриват",
        "навреден",
        "брадавица",
        "отпад",
        "потроши",
        "непотребно",
        "губење",
        "воден",
        "колеблив",
        "ослабен",
        "слабо",
        "слабост",
        "носат",
        "уморно",
        "замореност",
        "уморен",
        "плевел",
        "плачете",
        "чудно",
        "чудак",
        "NO TRANSLATION",
        "пропаст",
        "удар",
        "каприц",
        "лелекаат",
        "камшик",
        "виорот",
        "виски",
        "курва",
        "злите",
        "зло",
        "диви",
        "дива мачка",
        "шумски пожар",
        "намерно",
        "wimp",
        "wimpy",
        "Винкс",
        "вештерка",
        "вештерство",
        "се повлече",
        "венеат",
        "исушени",
        "горко",
        "очајни",
        "woefully",
        "зборови",
        "црв",
        "носи",
        "загрижени",
        "се грижи",
        "загрижувачки",
        "полошо",
        "влошување",
        "безвредни",
        "рана",
        "расправии",
        "гнев",
        "изливам",
        "руина",
        "уништен",
        "клуч",
        "борење",
        "беден",
        "беден",
        "погрешно",
        "прекршок",
        "погрешно",
        "погрешно",
        "ковано",
        "криво",
        "ксенофобија",
        "зево",
        "зевање",
        "викај",
        "жолти",
        "yelp",
        "zip",
    ]
)

_ambivalent = set(
    [
        "изобилство",
        "вооружени",
        "мелем",
        "се фалат",
        "весел",
        "bookworm",
        "долар",
        "славна личност",
        "шармиран",
        "заобиколување",
        "соучество",
        "признае",
        "лукав",
        "зависен",
        "разновидна",
        "доминираат",
        "бескрајни",
        "enforce",
        "еротски",
        "бегство",
        "чувство",
        "флертуваат",
        "град",
        "хедонизам",
        "највисоко",
        "смирен",
        "веднаш",
        "неподвижен",
        "приход",
        "инфилтрација",
        "влијание",
        "интензивно",
        "бескрајна",
        "интервенција",
        "чипка",
        "либерален",
        "Господарот",
        "мајчина",
        "бабица",
        "мајка",
        "кригла",
        "озлогласеност",
        "семоќност",
        "излив",
        "извонредна",
        "парада",
        "парафраза",
        "нафта",
        "презентација",
        "блудниот",
        "цитат",
        "рејвинг",
        "регресивно",
        "повторно",
        "останува",
        "пензионирање",
        "заживее",
        "револуција",
        "страшило",
        "изолација",
        "сензуална",
        "спектакл",
        "рбет",
        "фунта",
        "вкусен",
        "суеверие",
        "превласт",
        "опкружувачки",
        "синоним",
        "извонредно",
        "тинејџери",
        "третираат",
        "непобедлив",
        "неограничен",
        "неочекувано",
        "незамисливо",
        "одврзете",
        "тешка",
        "гласање",
        "Тежина",
        "копнеж",
    ]
)
